@@ -33,6 +33,7 @@ conf_library_types = {
 conf_iosImage_defaults = {
     'id': -1,
     'filename': '',
+    'baseconfig': '',
     'platform': '',
     'chassis': '',
     'idlepc': '',
@@ -44,6 +45,7 @@ conf_iosImage_defaults = {
 conf_iosImage_types = {
     'id': int,
     'filename': unicode,
+    'baseconfig': unicode,
     'platform': str,
     'chassis': str,
     'idlepc': str,
@@ -58,7 +60,8 @@ conf_hypervisor_defaults = {
     'port': 7200,
     'workdir': '',
     'baseUDP': 10000,
-    'baseConsole': 2000, 
+    'baseConsole': 2000,
+    'baseAUX': 2100,
     'used_ram':0, 
 }
 
@@ -68,7 +71,8 @@ conf_hypervisor_types = {
     'port': int,
     'workdir': unicode,
     'baseUDP': int,
-    'baseConsole': int, 
+    'baseConsole': int,
+    'baseAUX': int,
     'used_ram': int, 
 }
 
@@ -76,7 +80,8 @@ conf_qemuImage_defaults = {
     'id': -1,
     'name': '',
     'filename': '',
-    'memory': 128,
+    'memory': 256,
+    'nib_nb': 6,
     'nic': 'e1000',
     'options': '',
     'kqemu': False,
@@ -88,6 +93,111 @@ conf_qemuImage_types = {
     'name': unicode,
     'filename': unicode,
     'memory': int,
+    'nic_nb': int,
+    'nic': str,
+    'options': str,
+    'kqemu': bool,
+    'kvm': bool
+}
+
+conf_pixImage_defaults = {
+    'id': -1,
+    'name': '',
+    'filename': '',
+    'memory': 128,
+    'nib_nb': 6,
+    'nic': 'e1000',
+    'options': '',
+    'kqemu': False,
+    'key': '',
+    'serial': ''
+}
+
+conf_pixImage_types = {
+    'id': int,
+    'name': unicode,
+    'filename': unicode,
+    'memory': int,
+    'nic_nb': int,
+    'nic': str,
+    'options': str,
+    'kqemu': bool,
+    'key': str,
+    'serial': str
+}
+
+conf_junosImage_defaults = {
+    'id': -1,
+    'name': '',
+    'filename': '',
+    'memory': 96,
+    'nib_nb': 6,
+    'nic': 'e1000',
+    'options': '',
+    'kqemu': False,
+    'kvm': False
+}
+
+conf_junosImage_types = {
+    'id': int,
+    'name': unicode,
+    'filename': unicode,
+    'memory': int,
+    'nic_nb': int,
+    'nic': str,
+    'options': str,
+    'kqemu': bool,
+    'kvm': bool
+}
+
+conf_asaImage_defaults = {
+    'id': -1,
+    'name': '',
+    'memory': 256,
+    'nib_nb': 6,
+    'nic': 'e1000',
+    'options': '',
+    'kqemu': False,
+    'kvm': False,
+    'kernel': '',
+    'initrd': '',
+    'kernel_cmdline': ''
+}
+
+conf_asaImage_types = {
+    'id': int,
+    'name': unicode,
+    'memory': int,
+    'nic_nb': int,
+    'nic': str,
+    'options': str,
+    'kqemu': bool,
+    'kvm': bool,
+    'kernel': unicode,
+    'initrd': unicode,
+    'kernel_cmdline': unicode,
+}
+
+conf_idsImage_defaults = {
+    'id': -1,
+    'name': '',
+    'image1': '',
+    'image2': '',
+    'memory': 512,
+    'nib_nb': 3,
+    'nic': 'e1000',
+    'options': '',
+    'kqemu': False,
+    'kvm': False
+}
+
+conf_idsImage_types = {
+    'id': int,
+    'name': unicode,
+    'image1': unicode,
+    'image2': unicode,
+    'memory': int,
+    'nic_nb': int,
     'nic': str,
     'options': str,
     'kqemu': bool,
@@ -101,6 +211,7 @@ conf_systemDynamips_defaults = {
     'clean_workdir': True, 
     'baseUDP': 10000,
     'baseConsole': 2000,
+    'baseAUX': 2100,
     'ghosting': True,
     'jitsharing': False,
     'sparsemem': False,
@@ -108,6 +219,7 @@ conf_systemDynamips_defaults = {
     'memory_limit': 512,
     'udp_incrementation': 100,
     'import_use_HypervisorManager': True,
+    'allocateHypervisorPerIOS': True,
     'HypervisorManager_binding': u'localhost', 
 }
 
@@ -118,6 +230,7 @@ conf_systemDynamips_types = {
     'clean_workdir': bool, 
     'baseUDP': int,
     'baseConsole': int,
+    'baseAUX': int,
     'ghosting': bool,
     'jitsharing': bool,
     'sparsemem': bool,
@@ -125,6 +238,7 @@ conf_systemDynamips_types = {
     'memory_limit': int,
     'udp_incrementation': int,
     'import_use_HypervisorManager': bool,
+    'allocateHypervisorPerIOS': bool,
     'HypervisorManager_binding': unicode, 
 }
 
@@ -133,6 +247,7 @@ conf_systemGeneral_defaults = {
     'project_startup': True,
     'relative_paths': True,
     'slow_start': 0,
+    'autosave': 60,
     'term_cmd': '',
     'use_shell': True,
     'project_path': '.',
@@ -148,6 +263,7 @@ conf_systemGeneral_types = {
     'project_startup': bool,
     'relative_paths': bool,
     'slow_start': int,
+    'autosave': int,
     'use_shell': bool,
     'term_cmd': unicode,
     'project_path': unicode,
@@ -182,40 +298,6 @@ conf_systemQemu_defaults = {
     'qemuwrapper_port': 10525,
     'qemuwrapper_baseUDP': 20000,
     'qemuwrapper_baseConsole': 3000,
-    'default_qemu_image': '',
-    'default_qemu_memory': 256,
-    'default_qemu_nic': 'e1000',
-    'default_qemu_options': '',
-    'default_qemu_kqemu': False,
-    'default_qemu_kvm': False,
-    'default_pix_image': '',
-    'default_pix_memory': 128,
-    'default_pix_nic': 'e1000',
-    'default_pix_options': '',
-    'default_pix_kqemu': False,
-    'default_pix_key': '',
-    'default_pix_serial': '',
-    'default_junos_image': '',
-    'default_junos_memory': 96,
-    'default_junos_nic': 'e1000',
-    'default_junos_options': '',
-    'default_junos_kqemu': False,
-    'default_junos_kvm': False,
-    'default_asa_memory': 256,
-    'default_asa_nic': 'e1000',
-    'default_asa_options': '',
-    'default_asa_kqemu': False,
-    'default_asa_kvm': False,
-    'default_asa_kernel': '',
-    'default_asa_initrd': '',
-    'default_asa_kernel_cmdline': '',
-    'default_ids_image1': '',
-    'default_ids_image2': '',
-    'default_ids_memory': 512,
-    'default_ids_nic': 'e1000',
-    'default_ids_options': '',
-    'default_ids_kqemu': False,
-    'default_ids_kvm': False,
 }
 
 conf_systemQemu_types = {
@@ -230,38 +312,4 @@ conf_systemQemu_types = {
     'qemuwrapper_port': int,
     'qemuwrapper_baseUDP': int,
     'qemuwrapper_baseConsole': int,
-    'default_qemu_image': unicode,
-    'default_qemu_memory': int,
-    'default_qemu_nic': str,
-    'default_qemu_options': str,
-    'default_qemu_kqemu': bool,
-    'default_qemu_kvm': bool,
-    'default_pix_image': unicode,
-    'default_pix_memory': int,
-    'default_pix_nic': str,
-    'default_pix_options': str,
-    'default_pix_kqemu': bool,
-    'default_pix_key': str,
-    'default_pix_serial': str,
-    'default_junos_image': unicode,
-    'default_junos_memory': int,
-    'default_junos_nic': str,
-    'default_junos_options': str,
-    'default_junos_kqemu': bool,
-    'default_junos_kvm': bool,
-    'default_asa_memory': int,
-    'default_asa_nic': str,
-    'default_asa_options': str,
-    'default_asa_kqemu': bool,
-    'default_asa_kvm': bool,
-    'default_asa_kernel': unicode,
-    'default_asa_initrd': unicode,
-    'default_asa_kernel_cmdline': unicode,
-    'default_ids_image1': unicode,
-    'default_ids_image2': unicode,
-    'default_ids_memory': int,
-    'default_ids_nic': str,
-    'default_ids_options': str,
-    'default_ids_kqemu': bool,
-    'default_ids_kvm': bool,
 }
