@@ -41,7 +41,8 @@ class HypervisorManager(object):
         """ Shutdown all started hypervisors
         """
 
-        self.stopProcHypervisors()
+        for hypervisor in self.hypervisors:
+            hypervisor['proc_instance'].kill()
 
     def setDefaults(self):
         """ Set the default values for the hypervisor manager
@@ -51,44 +52,53 @@ class HypervisorManager(object):
         self.hypervisor_path = dynamips.path
         self.hypervisor_wd = dynamips.workdir
         self.baseConsole = dynamips.baseConsole
+        self.baseAUX = dynamips.baseAUX
         globals.hypervisor_baseport = dynamips.port
         globals.GApp.dynagen.globaludp = dynamips.baseUDP
 
-    def startNewHypervisor(self, port):
+    def startNewHypervisor(self, port, processcheck=True):
         """ Create a new dynamips process and start it
         """
 
         proc = QtCore.QProcess(globals.GApp.mainWindow)
+        
         if self.hypervisor_wd:
             # set the working directory
             proc.setWorkingDirectory(self.hypervisor_wd)
 
-        # test if a hypervisor is already running on this port
-        s = socket(AF_INET, SOCK_STREAM)
-        s.setblocking(0)
-        s.settimeout(300)
-        try:
-            s.connect(('localhost', port))
-            s.close()
-
-            reply = QtGui.QMessageBox.question(globals.GApp.mainWindow, translate("HypervisorManager", "Hypervisor Manager"), unicode(translate("HypervisorManager", "Apparently an hypervisor is already running on port %i, would you like to kill all Dynamips processes?")) % port,
-                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-            if reply == QtGui.QMessageBox.Yes:
-                if sys.platform.startswith('win'):            
-                    killAll(os.path.basename(self.hypervisor_path))
-                else:
-                    killAll('dynamips')
-
-            s.connect(('localhost', port))
-            s.close()
+        if processcheck:
+            # test if a hypervisor is already running on this port
+            s = socket(AF_INET, SOCK_STREAM)
+            s.setblocking(0)
+            s.settimeout(300)
+            try:
+                s.connect(('localhost', port))
+                s.close()
     
-            QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("HypervisorManager", "Hypervisor Manager"),
-                                       unicode(translate("HypervisorManager", "Something is still running on port %i, you will have to stop it manually or change port settings")) % port)
-
-            globals.hypervisor_baseport += 1
-            return None
-        except:
-            s.close()
+                reply = QtGui.QMessageBox.question(globals.GApp.mainWindow, translate("HypervisorManager", "Hypervisor Manager"), unicode(translate("HypervisorManager", "Apparently an hypervisor is already running on port %i, would you like to kill all Dynamips processes?")) % port,
+                                                   QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+                if reply == QtGui.QMessageBox.Yes:       
+                    killAll(os.path.basename(self.hypervisor_path))
+                    time.sleep(1)
+                else:
+                    print "Incrementing +100 for base console port, base AUX port, base hypervisor port and base UDP port"
+                    self.baseConsole += 100
+                    if self.baseAUX:
+                        self.baseAUX += 100
+                    globals.hypervisor_baseport += 100
+                    globals.GApp.dynagen.globaludp += 100
+                    port = globals.hypervisor_baseport
+    
+                s.connect(('localhost', port))
+                s.close()
+        
+                QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("HypervisorManager", "Hypervisor Manager"),
+                                           unicode(translate("HypervisorManager", "A program is still running on port %i, you will have to stop it manually or change port settings")) % port)
+    
+                globals.hypervisor_baseport += 1
+                return None
+            except:
+                s.close()
 
         # start dynamips in hypervisor mode (-H)
         proc.start( self.hypervisor_path ,  ['-H', str(port)])
@@ -98,8 +108,9 @@ class HypervisorManager(object):
             return None
 
         hypervisor = {'port': port,
-                            'proc_instance': proc,
-                            'load': 0}
+                      'proc_instance': proc,
+                      'load': 0,
+                      'image_ref': ''}
 
         self.hypervisors.append(hypervisor)
         return hypervisor
@@ -168,6 +179,8 @@ class HypervisorManager(object):
         for hypervisor in self.hypervisors:
             if not isinstance(node, IOSRouter) or (isinstance(node, IOSRouter) and hypervisor['load'] + node.default_ram <= globals.GApp.systconf['dynamips'].memory_limit):
                 if isinstance(node, IOSRouter):
+                    if globals.GApp.systconf['dynamips'].allocateHypervisorPerIOS and hypervisor['image_ref'] != node.image_reference:
+                        continue
                     hypervisor['load'] += node.default_ram
                 debug('Hypervisor manager: allocates an already started hypervisor (port: ' + str(hypervisor['port']) + ')')
                 if not globals.GApp.dynagen.dynamips.has_key(globals.GApp.systconf['dynamips'].HypervisorManager_binding + ':' + str(hypervisor['port'])):
@@ -185,6 +198,8 @@ class HypervisorManager(object):
 
         if isinstance(node, IOSRouter):
             hypervisor['load'] = node.default_ram
+            hypervisor['image_ref'] = node.image_reference
+
         # use project workdir in priority
         if globals.GApp.workspace.projectWorkdir:
             if not os.access(globals.GApp.workspace.projectWorkdir, os.F_OK | os.W_OK):
@@ -196,11 +211,15 @@ class HypervisorManager(object):
                 QtGui.QMessageBox.warning(globals.GApp.mainWindow, 'HypervisorManager', 
                                           unicode(translate("HypervisorManager", "Working directory %s seems to not exist or be writable, please check")) % self.hypervisor_wd)
             globals.GApp.dynagen.defaults_config['workingdir'] = self.hypervisor_wd
-        dynamips_hypervisor = globals.GApp.dynagen.create_dynamips_hypervisor(globals.GApp.systconf['dynamips'].HypervisorManager_binding, hypervisor['port'])
+        try:
+            dynamips_hypervisor = globals.GApp.dynagen.create_dynamips_hypervisor(globals.GApp.systconf['dynamips'].HypervisorManager_binding, hypervisor['port'])
+        except:
+            dynamips_hypervisor = None
         if not dynamips_hypervisor:
             QtGui.QMessageBox.critical(globals.GApp.mainWindow, 'Hypervisor Manager',
                                         unicode(translate("HypervisorManager", "Can't set up hypervisor on port %i, please check the settings (writable working directory ...)")) % hypervisor['port'])
-            del globals.GApp.dynagen.dynamips[globals.GApp.systconf['dynamips'].HypervisorManager_binding + ':' + str(hypervisor['port'])]
+            if globals.GApp.dynagen.dynamips.has_key(globals.GApp.systconf['dynamips'].HypervisorManager_binding + ':' + str(hypervisor['port'])):
+                del globals.GApp.dynagen.dynamips[globals.GApp.systconf['dynamips'].HypervisorManager_binding + ':' + str(hypervisor['port'])]
             hypervisor['proc_instance'].close()
             hypervisor['proc_instance'] = None
             count = 0
@@ -216,6 +235,7 @@ class HypervisorManager(object):
         dynamips_hypervisor.udp = globals.GApp.dynagen.globaludp
         dynamips_hypervisor.starting_udp = globals.GApp.dynagen.globaludp
         dynamips_hypervisor.baseconsole = self.baseConsole
+        dynamips_hypervisor.baseaux = self.baseAUX
         globals.GApp.dynagen.globaludp += globals.GApp.systconf['dynamips'].udp_incrementation
         node.set_hypervisor(dynamips_hypervisor)
         return hypervisor
