@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: expandtab ts=4 sw=4 sts=4:
 #
-# Copyright (C) 2007-2008 GNS3 Dev Team
+# Copyright (C) 2007-2010 GNS3 Development Team (http://www.gns3.net/team).
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -16,14 +16,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #
-# Contact: contact@gns3.net
+# code@gns3.net
 #
 
-import os, re
+import sys, os, re
 import GNS3.Globals as globals
-from PyQt4 import QtCore, QtGui, QtNetwork
+from PyQt4 import QtCore, QtGui
 from GNS3.Ui.Form_IOSDialog import Ui_IOSDialog
-from GNS3.Config.Config import ConfDB
 from GNS3.Utils import fileBrowser, translate, testOpenFile
 from GNS3.Config.Objects import iosImageConf, hypervisorConf
 from GNS3.Node.IOSRouter import IOSRouter
@@ -59,19 +58,16 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
 
         # connections to slots
         self.connect(self.pushButtonSaveIOS, QtCore.SIGNAL('clicked()'), self.slotSaveIOS)
-        self.connect(self.pushButtonEditIOS,  QtCore.SIGNAL('clicked()'),  self.slotEditIOS)
         self.connect(self.pushButtonDeleteIOS, QtCore.SIGNAL('clicked()'), self.slotDeleteIOS)
         self.connect(self.pushButtonSelectIOSImage, QtCore.SIGNAL('clicked()'), self.slotSelectIOS)
+        self.connect(self.pushButtonSelectBaseConfig, QtCore.SIGNAL('clicked()'), self.slotBaseConfig)
         self.connect(self.pushButtonSaveHypervisor, QtCore.SIGNAL('clicked()'), self.slotSaveHypervisor)
-        self.connect(self.pushButtonEditHypervisor,  QtCore.SIGNAL('clicked()'),  self.slotEditHypervisor)
         self.connect(self.pushButtonDeleteHypervisor, QtCore.SIGNAL('clicked()'), self.slotDeleteHypervisor)
         self.connect(self.pushButtonSelectWorkingDir, QtCore.SIGNAL('clicked()'), self.slotWorkingDirectory)
         self.connect(self.checkBoxIntegratedHypervisor, QtCore.SIGNAL('stateChanged(int)'), self.slotCheckBoxIntegratedHypervisor)
         self.connect(self.comboBoxPlatform, QtCore.SIGNAL('currentIndexChanged(const QString &)'), self.slotSelectedPlatform)
         self.connect(self.treeWidgetIOSimages,  QtCore.SIGNAL('itemSelectionChanged()'),  self.slotIOSSelectionChanged)
-        self.connect(self.treeWidgetIOSimages,  QtCore.SIGNAL('itemActivated(QTreeWidgetItem *, int)'),  self.slotIOSSelected)
         self.connect(self.treeWidgetHypervisor, QtCore.SIGNAL('itemSelectionChanged()'),  self.slotHypervisorSelectionChanged)
-        self.connect(self.treeWidgetHypervisor,  QtCore.SIGNAL('itemActivated(QTreeWidgetItem *, int)'),  self.slotHypervisorSelected)
         self.connect(self.labelCheckRAM,  QtCore.SIGNAL('linkActivated(const QString &)'), self.slotCheckRAMrequirement)
         
         # insert known platforms
@@ -85,7 +81,6 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
 
         # reload saved infos
         self._reloadInfos()
-        self.selectionChanged = True
 
     def __del__(self):
 
@@ -175,11 +170,24 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
             if not testOpenFile(path):
                 QtGui.QMessageBox.critical(self, translate("IOSDialog", "IOS Configuration"), unicode(translate("IOSDialog", "Can't open file: %s")) % path)
                 return
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(self, translate("IOSDialog", "IOS Configuration"), translate("IOSDialog", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
 
             self.lineEditIOSImage.clear()
             self.lineEditIOSImage.setText(path)
+            
+            # basename doesn't work on Unix with Windows paths, so let's use this little trick
+            image = path
+            if not sys.platform.startswith('win') and image[1] == ":":
+                image = image[2:]
+                image = image.replace("\\", "/")
+                
             # try to guess the platform
-            platform = self._getIOSplatform(os.path.basename(path))
+            platform = self._getIOSplatform(os.path.basename(image))
             if platform == '2600':
                 # force c2600 platform
                 index = self.comboBoxPlatform.findText('c2600')
@@ -205,6 +213,29 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
                                 self.spinBoxDefaultRAM.setValue(DEFAULT_RAM[platformname])
                             break
 
+    def slotBaseConfig(self):
+        """ Get an base config file from the file system
+        """
+        
+        # get the path to the ios image
+        path = fileBrowser(translate("IOSDialog", "Select a Base configuration file"),  directory='.', parent=self).getFile()
+
+        if path != None and path[0] != '':
+            path = os.path.normpath(path[0])
+            # test if we can open it
+            if not testOpenFile(path):
+                QtGui.QMessageBox.critical(self, translate("IOSDialog", "IOS Configuration"), unicode(translate("IOSDialog", "Can't open file: %s")) % path)
+                return
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(self, translate("IOSDialog", "IOS Configuration"), translate("IOSDialog", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
+            
+            self.lineEditBaseConfig.clear()
+            self.lineEditBaseConfig.setText(path)
+
     def slotSaveIOS(self):
         """ Save an IOS image and all his settings
         """
@@ -243,12 +274,6 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
         else:
             imagekey = globals.GApp.systconf['dynamips'].HypervisorManager_binding + ':' + imagename
 
-        current_item = self.treeWidgetIOSimages.currentItem()
-        if current_item:
-            image = unicode(current_item.text(0))
-            if self.selectionChanged == False and globals.GApp.iosimages.has_key(image) and image.rsplit(':', 1)[1] == imagename:
-                del globals.GApp.iosimages[image]
-                self.treeWidgetIOSimages.takeTopLevelItem(self.treeWidgetIOSimages.indexOfTopLevelItem(current_item))
 
         if globals.GApp.iosimages.has_key(imagekey):
             # update an already existing IOS image
@@ -262,7 +287,6 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
             # chassis column
             item.setText(1, self.comboBoxChassis.currentText())
             self.treeWidgetIOSimages.setCurrentItem(item)
-            self.selectionChanged = False
 
         # save settings
         if globals.GApp.iosimages.has_key(imagekey):
@@ -273,6 +297,7 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
         conf.id = globals.GApp.iosimages_ids
         globals.GApp.iosimages_ids += 1
         conf.filename = imagename
+        conf.baseconfig = unicode(self.lineEditBaseConfig.text())
         conf.platform = str(self.comboBoxPlatform.currentText())
         conf.chassis = str(self.comboBoxChassis.currentText())
         conf.idlepc = idlepc
@@ -298,6 +323,7 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
         else:
             conf.default = False
         globals.GApp.iosimages[imagekey] = conf
+        self.treeWidgetIOSimages.update()
         self.treeWidgetIOSimages.resizeColumnToContents(0)
 
     def slotDeleteIOS(self):
@@ -310,37 +336,19 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
             image = unicode(item.text(0))
             del globals.GApp.iosimages[image]
 
-    def slotEditIOS(self):
-        """ Edit the selected line from the list of IOS images
-        """
-
-        item = self.treeWidgetIOSimages.currentItem()
-        self.slotIOSSelected(item, 0)
-
     def slotIOSSelectionChanged(self):
         """ Check if an entry is selected in the list of IOS images
         """
 
-        self.selectionChanged = True
         item = self.treeWidgetIOSimages.currentItem()
         if item != None:
-            self.pushButtonEditIOS.setEnabled(True)
-            self.pushButtonDeleteIOS.setEnabled(True)
-        else:
-            self.pushButtonEditIOS.setEnabled(False)
-            self.pushButtonDeleteIOS.setEnabled(False)
-
-    def slotIOSSelected(self,  item, column):
-        """ Load IOS settings into the GUI when selecting an entry in the list of IOS images
-        """
-
-        if (item != None):
-            # restore image name
+            self.pushButtonDeleteIOS.setEnabled(True) 
             imagekey = unicode(item.text(0))
             self.selectionChanged = False
             if globals.GApp.iosimages.has_key(imagekey):
                 conf = globals.GApp.iosimages[imagekey]
                 self.lineEditIOSImage.setText(conf.filename)
+                self.lineEditBaseConfig.setText(conf.baseconfig)
                 index = self.comboBoxPlatform.findText(conf.platform, QtCore.Qt.MatchFixedString)
                 self.comboBoxPlatform.setCurrentIndex(index)
                 index = self.comboBoxChassis.findText(conf.chassis, QtCore.Qt.MatchFixedString)
@@ -360,13 +368,15 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
                         if items:
                             items[0].setSelected(True)
                 else:
-                    self.checkBoxIntegratedHypervisor.setCheckState(QtCore.Qt.Checked)
+                    self.checkBoxIntegratedHypervisor.setCheckState(QtCore.Qt.Checked) 
+        else:
+            self.pushButtonDeleteIOS.setEnabled(False)
 
     def slotCheckRAMrequirement(self, link):
         """ Check for minimum RAM requirement
         """
 
-        image_file = str(self.lineEditIOSImage.text())
+        image_file = unicode(self.lineEditIOSImage.text())
         if not image_file:
             QtGui.QMessageBox.warning(self, translate("IOSDialog", "IOS Configuration"), translate("IOSDialog", "Image file box is empty"))
             return
@@ -397,6 +407,12 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
         if path:
             self.lineEditWorkingDir.clear()
             self.lineEditWorkingDir.setText(os.path.normpath(path))
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(self, translate("IOSDialog", "IOS Configuration"), translate("IOSDialog", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
 
     def slotSaveHypervisor(self):
         """ Save a hypervisor to the hypervisors list
@@ -436,6 +452,7 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
             conf.workdir = working_dir
             conf.baseUDP = baseudp
             conf.baseConsole = self.spinBoxBaseConsole.value()
+            conf.baseAUX = self.spinBoxBaseAUX.value()
             self.spinBoxBaseUDP.setValue(conf.baseUDP + 100)
             self.spinBoxBaseConsole.setValue(conf.baseConsole + 10)
             globals.GApp.hypervisors[hypervisorkey] = conf
@@ -448,18 +465,11 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
 
         item = self.treeWidgetHypervisor.currentItem()
         if (item != None):
-           self.treeWidgetHypervisor.takeTopLevelItem(self.treeWidgetHypervisor.indexOfTopLevelItem(item))
-           hypervisorkey = str(item.text(0))
-           items = self.listWidgetHypervisors.findItems(hypervisorkey, QtCore.Qt.MatchFixedString)
-           self.listWidgetHypervisors.takeItem(self.listWidgetHypervisors.row(items[0]))
-           del globals.GApp.hypervisors[hypervisorkey]
-
-    def slotEditHypervisor(self):
-        """ Edit the selected line from the list of hypervisors
-        """
-
-        item = self.treeWidgetHypervisor.currentItem()
-        self.slotHypervisorSelected(item, 0)
+            self.treeWidgetHypervisor.takeTopLevelItem(self.treeWidgetHypervisor.indexOfTopLevelItem(item))
+            hypervisorkey = str(item.text(0))
+            items = self.listWidgetHypervisors.findItems(hypervisorkey, QtCore.Qt.MatchFixedString)
+            self.listWidgetHypervisors.takeItem(self.listWidgetHypervisors.row(items[0]))
+            del globals.GApp.hypervisors[hypervisorkey]
 
     def slotHypervisorSelectionChanged(self):
         """ Check if an entry is selected in the list of hypervisors
@@ -467,17 +477,7 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
 
         item = self.treeWidgetHypervisor.currentItem()
         if item != None:
-            self.pushButtonEditHypervisor.setEnabled(True)
             self.pushButtonDeleteHypervisor.setEnabled(True)
-        else:
-            self.pushButtonEditHypervisor.setEnabled(False)
-            self.pushButtonDeleteHypervisor.setEnabled(False)
-
-    def slotHypervisorSelected(self,  item,  column):
-        """ Load hypervisor settings into the GUI when selecting an entry in the list of hypervisors
-        """
-
-        if (item != None):
             hypervisor_key = unicode(item.text(0))
             if globals.GApp.hypervisors.has_key(hypervisor_key):
                 conf = globals.GApp.hypervisors[hypervisor_key]
@@ -486,3 +486,7 @@ class IOSDialog(QtGui.QDialog, Ui_IOSDialog):
                 self.lineEditWorkingDir.setText(conf.workdir)
                 self.spinBoxBaseUDP.setValue(conf.baseUDP)
                 self.spinBoxBaseConsole.setValue(conf.baseConsole)
+                self.spinBoxBaseAUX.setValue(conf.baseAUX)
+        else:
+            self.pushButtonDeleteHypervisor.setEnabled(False)
+
