@@ -349,8 +349,7 @@ class AbstractEdge(QtGui.QGraphicsPathItem, QtCore.QObject):
             else:
                 (device, slot, inttype, port) = self.captureInfo
                 globals.GApp.dynagen.devices[device].slot[slot].filter(inttype, port, 'none', 'both')
-            if showMessage:
-                QtGui.QMessageBox.information(globals.GApp.mainWindow, translate("AbstractEdge", "Capture"),  translate("AbstractEdge", "Capture stopped"))
+
             self.capturing = False
             self.captureInfo = None
             self.capfile = None
@@ -385,7 +384,7 @@ class AbstractEdge(QtGui.QGraphicsPathItem, QtCore.QObject):
             return
 
         try:
-            path = capture_conf.cap_cmd.replace("%c", '"' + self.capfile + '"')
+            path = unicode(capture_conf.cap_cmd.replace("%c", '"%s"')) % self.capfile
             debug("Start Wireshark like application: " + path)
             if sys.platform.startswith('win'):
                 sub.Popen(path)
