@@ -119,9 +119,8 @@ class Ethernet(AbstractEdge):
             if globals.GApp.workspace.flg_showInterfaceNames:
                 if self.labelSouceIf == None:
 
-                    self.labelSouceIf = Annotation(self.source)
-
                     if globals.interfaceLabels.has_key(self.source.hostname + ' ' + self.srcIf):
+                        self.labelSouceIf = Annotation(self.source)
                         annotation = globals.interfaceLabels[self.source.hostname + ' ' + self.srcIf]
                         self.labelSouceIf.setZValue(annotation.zValue())
                         self.labelSouceIf.setDefaultTextColor(annotation.defaultTextColor())
@@ -131,15 +130,19 @@ class Ethernet(AbstractEdge):
                         self.labelSouceIf.rotation = annotation.rotation
                         self.labelSouceIf.rotate(annotation.rotation)
                         del globals.interfaceLabels[self.source.hostname + ' ' + self.srcIf]
-                    else:
+                    elif not globals.GApp.workspace.flg_showOnlySavedInterfaceNames:
+                        self.labelSouceIf = Annotation(self.source)
                         self.labelSouceIf.setPlainText(self.srcIf)
                         self.labelSouceIf.setPos(self.mapToItem(self.source, point1))
-                        self.labelSouceIf.autoGenerated = True
+                        #self.labelSouceIf.autoGenerated = True
 
-                    self.labelSouceIf.deviceName = self.source.hostname
-                    self.labelSouceIf.deviceIf = self.srcIf
-                if not self.labelSouceIf.isVisible():
+                    if self.labelSouceIf:
+                        self.labelSouceIf.deviceName = self.source.hostname
+                        self.labelSouceIf.deviceIf = self.srcIf
+
+                if self.labelSouceIf and not self.labelSouceIf.isVisible():
                     self.labelSouceIf.show()
+
             elif self.labelSouceIf and globals.GApp.workspace.flg_showInterfaceNames == False:
                 self.labelSouceIf.hide()
 
@@ -167,11 +170,10 @@ class Ethernet(AbstractEdge):
                     self.dstCollisionOffset -= 10
 
             if globals.GApp.workspace.flg_showInterfaceNames:
-                if self.labelDestIf  == None:
-                    
-                    self.labelDestIf = Annotation(self.dest)
-                    
+                if self.labelDestIf == None:
+
                     if globals.interfaceLabels.has_key(self.dest.hostname + ' ' + self.destIf):
+                        self.labelDestIf = Annotation(self.dest)
                         annotation = globals.interfaceLabels[self.dest.hostname + ' ' + self.destIf]
                         self.labelDestIf.setZValue(annotation.zValue())
                         self.labelDestIf.setDefaultTextColor(annotation.defaultTextColor())
@@ -181,15 +183,19 @@ class Ethernet(AbstractEdge):
                         self.labelDestIf.rotation = annotation.rotation
                         self.labelDestIf.rotate(annotation.rotation)
                         del globals.interfaceLabels[self.dest.hostname + ' ' + self.destIf]
-                    else:
+                    elif not globals.GApp.workspace.flg_showOnlySavedInterfaceNames:
+                        self.labelDestIf = Annotation(self.dest)
                         self.labelDestIf.setPlainText(self.destIf)
                         self.labelDestIf.setPos(self.mapToItem(self.dest, point2))
-                        self.labelDestIf.autoGenerated = True
+                        #self.labelDestIf.autoGenerated = True
 
-                    self.labelDestIf.deviceName = self.dest.hostname
-                    self.labelDestIf.deviceIf = self.destIf
-                if not self.labelDestIf.isVisible():
+                    if self.labelDestIf:
+                        self.labelDestIf.deviceName = self.dest.hostname
+                        self.labelDestIf.deviceIf = self.destIf
+
+                if self.labelDestIf and not self.labelDestIf.isVisible():
                     self.labelDestIf.show()
+
             elif self.labelDestIf and globals.GApp.workspace.flg_showInterfaceNames == False:
                 self.labelDestIf.hide()
 
