@@ -26,7 +26,7 @@ import GNS3.Dynagen.dynamips_lib as lib
 import GNS3.Dynagen.qemu_lib as qlib
 from GNS3.Globals.Symbols import SYMBOLS
 from GNS3.Utils import translate, debug, error
-from PyQt4 import QtGui, QtCore
+from PyQt4 import QtGui, QtCore, QtSvg
 from GNS3.Annotation import Annotation
 from GNS3.Pixmap import Pixmap
 from GNS3.ShapeItem import AbstractShapeItem
@@ -190,36 +190,57 @@ class NETFile(object):
             if config.has_key('symbol'):
                 symbol_name = config['symbol']
 
-        # symbol name not found, use default one
-        default_symbol = False
-        if not symbol_name or not globals.GApp.scene.renders.has_key(symbol_name):
-            symbol_name = default_symbol_name
-            default_symbol = True
+        node = None
+        if symbol_name:
+            for item in SYMBOLS:
+                if item['name'] == default_symbol_name:
+                    symbol_resources = QtCore.QResource(":/symbols")
+                    for symbol in symbol_resources.children():
+                        symbol = str(symbol)
+                        if symbol.startswith(symbol_name):
+                            normal_renderer = QtSvg.QSvgRenderer(':/symbols/' + symbol_name + '.normal.svg')
+                            select_renderer = QtSvg.QSvgRenderer(':/symbols/' + symbol_name + '.selected.svg')
+                            node = item['object'](normal_renderer, select_renderer)
+                            node.type = symbol_name
+                            node.default_symbol = False
+                            break
+                    break
 
-        for item in SYMBOLS:
-            if item['name'] == symbol_name:
-                renders = globals.GApp.scene.renders[symbol_name]
-                node = item['object'](renders['normal'], renders['selected'])
-                node.set_hostname(device.name)
-                node.type = item['name']
-                if not default_symbol:
-                    node.default_symbol = False
-                if x == None:
-                    x = random.uniform(-200, 200)
-                if y == None:
-                    y = random.uniform(-200, 200)
-                node.setPos(float(x), float(y))
-                if z:
-                    node.setZValue(float(z))
-                if hx and hy:
-                    node.hostname_xpos = float(hx)
-                    node.hostname_ypos = float(hy)
-                if globals.GApp.workspace.flg_showHostname == True:
-                    node.showHostname()
-                debug("Node created: " + str(node))
-                return node
+        if not node:
+            # symbol name not found, use default one
+            default_symbol = False
+            if not symbol_name or not globals.GApp.scene.renders.has_key(symbol_name):
+                symbol_name = default_symbol_name
+                default_symbol = True
     
-        return None
+    
+            for item in SYMBOLS:
+                if item['name'] == symbol_name:
+                    renders = globals.GApp.scene.renders[symbol_name]
+                    node = item['object'](renders['normal'], renders['selected'])
+                    node.type = item['name']
+                    if not default_symbol:
+                        node.default_symbol = False
+                    break
+        
+        if not node:    
+            return None
+             
+        node.set_hostname(device.name)       
+        if x == None:
+            x = random.uniform(-200, 200)
+        if y == None:
+            y = random.uniform(-200, 200)
+        node.setPos(float(x), float(y))
+        if z:
+            node.setZValue(float(z))
+        if hx and hy:
+            node.hostname_xpos = float(hx)
+            node.hostname_ypos = float(hy)
+        if globals.GApp.workspace.flg_showHostname == True:
+            node.showHostname()
+        debug("Node created: " + str(node))
+        return node
 
     def record_image(self, device):
         """ Record an image and all its settings in GNS3
@@ -255,6 +276,7 @@ class NETFile(object):
             conf_hypervisor.workdir = unicode(device.dynamips.workingdir)
             conf_hypervisor.baseUDP = device.dynamips.udp
             conf_hypervisor.baseConsole = device.dynamips.baseconsole
+            conf_hypervisor.baseAUX = device.dynamips.baseaux
             globals.GApp.hypervisors[conf_hypervisor.host + ':' + str(conf_hypervisor.port)] = conf_hypervisor
             globals.GApp.iosimages[host + ':' + device.image] = conf_image
 
@@ -330,6 +352,7 @@ class NETFile(object):
         globals.GApp.topology.nodes[cloud.id] = cloud
         if globals.GApp.workspace.flg_showHostname == True:
             cloud.showHostname()
+            
         globals.GApp.topology.addItem(cloud)
         return cloud
 
@@ -353,15 +376,30 @@ class NETFile(object):
                 except ValueError:
                     continue
                 if devtype.lower() == 'cloud':
+
                     default_symbol = True
-                    if gns3data[section].has_key('symbol') and globals.GApp.scene.renders.has_key(gns3data[section]['symbol']):
-                        symbol = gns3data[section]['symbol']
-                        default_symbol = False
-                    else:
-                        symbol = 'Cloud'
-                    renders = globals.GApp.scene.renders[symbol]
-                    cloud = Cloud(renders['normal'], renders['selected'])
-                    cloud.type = symbol
+                    if gns3data[section].has_key('symbol') and gns3data[section]['symbol']:
+                        symbol_name = gns3data[section]['symbol']
+
+                        symbol_resources = QtCore.QResource(":/symbols")
+                        for symbol in symbol_resources.children():
+                            symbol = str(symbol)
+                            if symbol.startswith(symbol_name):
+                                normal_renderer = QtSvg.QSvgRenderer(':/symbols/' + symbol_name + '.normal.svg')
+                                select_renderer = QtSvg.QSvgRenderer(':/symbols/' + symbol_name + '.selected.svg')
+                                default_symbol = False
+                                break
+
+                    if default_symbol:
+                        symbol_name = 'Cloud'
+                        normal_renderer = globals.GApp.scene.renders[symbol_name]['normal']
+                        select_renderer = globals.GApp.scene.renders[symbol_name]['selected']
+
+
+                    cloud = Cloud(normal_renderer, select_renderer)
+                    config = {}
+                    config['nios'] = []
+                    cloud.type = symbol_name
                     if not default_symbol:
                         cloud.default_symbol = False
                     cloud.hostname = unicode(hostname)
@@ -376,13 +414,11 @@ class NETFile(object):
                         cloud.hostname_ypos = float(gns3data[section]['hy'])
                     if gns3data[section].has_key('connections'):
                         connections = gns3data[section]['connections'].split(' ')
-                        config = {}
-                        config['nios'] = []
                         for connection in connections:
                             (device, interface, nio) = connection.split(':', 2)
                             self.connection2cloud[(device, interface, nio.lower())] = cloud
                             config['nios'].append(nio)
-                        cloud.set_config(config)
+                    cloud.set_config(config)
                     QtCore.QObject.connect(cloud, QtCore.SIGNAL("Add link"), globals.GApp.scene.slotAddLink)
                     QtCore.QObject.connect(cloud, QtCore.SIGNAL("Delete link"), globals.GApp.scene.slotDeleteLink)
                     globals.GApp.topology.nodes[cloud.id] = cloud
@@ -508,6 +544,9 @@ class NETFile(object):
             init_cloud_id(max_cloud_id + 1)
         if max_decorative_id != -1:
             init_decoration_id(max_decorative_id + 1)
+            
+        if len(globals.interfaceLabels):
+            globals.GApp.workspace.flg_showOnlySavedInterfaceNames = True
 
     def apply_decorative_node_connections(self):
         """ Create GUI connections for decorative nodes
@@ -541,7 +580,8 @@ class NETFile(object):
             splash.showMessage(translate("NETFile", "Please wait while importing the topology"))
             globals.GApp.processEvents(QtCore.QEventLoop.AllEvents | QtCore.QEventLoop.WaitForMoreEvents, 1000)
             self.dynagen.ghosting()
-            self.dynagen.jitsharing()
+            if globals.GApp.systconf['dynamips'].jitsharing:
+                self.dynagen.jitsharing()
         except lib.DynamipsError, msg:
             QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("NETFile", "Dynamips error"),  unicode(msg))
             globals.GApp.workspace.projectFile = None
@@ -578,7 +618,7 @@ class NETFile(object):
         max_atmsw_id = -1
         max_atmbr_id = -1
         max_emu_id = -1
-        for (devicename, device) in  self.dynagen.devices.iteritems():
+        for (devicename, device) in self.dynagen.devices.iteritems():
 
             if isinstance(device,  lib.Bridge):
                 translate("NETFile", "Warning: GNS3 doesn't yet support lan statements, ignore it")
@@ -705,8 +745,8 @@ class NETFile(object):
                 keys = device.mapping.keys()
                 keys.sort()
                 for port1 in keys:
-                    (port2, vci2, vpi2) = device.mapping[port1]
-                    config['mapping'][str(port1)] = str(port2) + ':' + str(vci2) + ':' + str(vpi2)
+                    (port2, vpi, vci) = device.mapping[port1]
+                    config['mapping'][str(port1)] = str(port2) + ':' + str(vpi) + ':' + str(vci)
                     if not port1 in config['ports']:
                         config['ports'].append(port1)
                     if not port2 in config['ports']:
@@ -797,19 +837,22 @@ class NETFile(object):
         for node in globals.GApp.topology.nodes.itervalues():
             node.updateToolTips()
 
-    def export_router_config(self, device):
+    def export_router_config(self, device, auto=False):
 
         try:
             config = base64.decodestring(device.config_b64)
-            config = config.replace('\r', "")
+            config = '!\n' + config.replace('\r', "")
             # Write out the config to a file
             file_path = os.path.normpath(globals.GApp.workspace.projectConfigs) + os.sep + device.name + '.cfg'
-            print unicode(translate("NETFile", "Exporting %s configuration to %s")) % (device.name, file_path)
+            if auto == False:
+                print unicode(translate("NETFile", "Exporting %s configuration to %s")) % (device.name, file_path)
         except lib.DynamipsError, msg:
-            print unicode(device.name + ': ' + translate("NETFile", "Dynamips error") + ': ') + unicode(msg)
+            if auto == False:
+                print unicode(device.name + ': ' + translate("NETFile", "Dynamips error") + ': ') + unicode(msg)
             return
         except lib.DynamipsWarning, msg:
-            print unicode(device.name + ': ' + translate("NETFile", "Dynamips warning") + ': ') + unicode(msg)
+            if auto == False:
+                print unicode(device.name + ': ' + translate("NETFile", "Dynamips warning") + ': ') + unicode(msg)
             return
         except:
             error('Unknown error exporting config for ' + device.name)
@@ -825,7 +868,7 @@ class NETFile(object):
                                       unicode(device.name) + ': ' + translate("NETFile", "IOError"), unicode(translate("NETFile", "%s: IO Error: %s")) % (file_path, unicode(e)))
             return
 
-    def export_net_file(self, path):
+    def export_net_file(self, path, auto=False):
         """ Export a .net file
         """
 
@@ -850,7 +893,7 @@ class NETFile(object):
         for device in self.dynagen.devices.values():
             # record router configs
             if isinstance(device, lib.Router) and globals.GApp.workspace.projectConfigs:
-                self.export_router_config(device)
+                self.export_router_config(device, auto)
 
         note_nb = 1
         shape_nb = 1
@@ -884,7 +927,7 @@ class NETFile(object):
                 if connections:
                     config['connections'] = connections.strip()
             # record notes
-            elif isinstance(item, Annotation) and item.autoGenerated == False:
+            elif isinstance(item, Annotation): #and item.autoGenerated == False:
                 if not self.dynagen.running_config.has_key('GNS3-DATA'):
                     self.dynagen.running_config['GNS3-DATA'] = {}
                 self.dynagen.running_config['GNS3-DATA']['NOTE ' + str(note_nb)] = {}
