@@ -19,7 +19,7 @@
 # code@gns3.net
 #
 
-import os, shutil, glob, sys
+import os, shutil, glob, sys, base64, time
 import GNS3.Globals as globals
 import GNS3.Dynagen.dynamips_lib as lib
 import GNS3.Dynagen.dynagen as dynagen_namespace
@@ -60,6 +60,8 @@ class IOSRouter(AbstractNode):
 
         # assign a new hostname
         global router_id
+        if not router_id:
+            router_id = 1
 
         # check if hostname has already been assigned
         for node in globals.GApp.topology.nodes.itervalues():
@@ -149,13 +151,26 @@ class IOSRouter(AbstractNode):
         self.hostname = hostname
         self.r = 'ROUTER ' + self.hostname
         self.updateToolTips()
+        
+    def changeHostname(self):
+        """ Called to change the hostname
+        """
+        
+        if self.router.state != 'stopped':
+            QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("IOSRouter", "New hostname"),
+                                       translate("IOSRouter", "Cannot change the hostname of a running device"))            
+            return
+        AbstractNode.changeHostname(self)
 
     def setCustomToolTip(self):
         """ Set a custom tool tip
         """
 
         if self.router:
-            self.setToolTip(self.router.info())
+            try:
+                self.setToolTip(self.router.info())
+            except:
+                AbstractNode.setCustomToolTip(self)
         else:
             AbstractNode.setCustomToolTip(self)
 
@@ -238,27 +253,38 @@ class IOSRouter(AbstractNode):
         for module_name in config['slots']:
             if module_name and self.router.slot[slot_number] == None:
                 self.set_slot(slot_number, module_name)
-                slot_changed = True
+                if self.router.slot[slot_number] and not self.router.slot[slot_number].can_be_removed():
+                    slot_changed = True
             elif self.router.slot[slot_number] and module_name and module_name != self.router.slot[slot_number].adapter:
                 self.clean_slot(self.router.slot[slot_number])
                 self.set_slot(slot_number, module_name)
-                slot_changed = True
+                if self.router.slot[slot_number] and not self.router.slot[slot_number].can_be_removed():
+                    slot_changed = True
             elif module_name == None and self.router.slot[slot_number]:
                 self.clean_slot(self.router.slot[slot_number])
             slot_number += 1
 
-        if slot_changed and self.router.state == "running" and self.router.model != "c7200":
+        if slot_changed and self.router.model != 'c7200' and self.state == 'running':
             QtGui.QMessageBox.warning(globals.GApp.mainWindow, translate("IOSRouter", "Slots"), translate("IOSRouter", "You have to restart this router to use new modules"))
 
-        # configure wics if available
-        if config['wics']:
-            wic_number = 0
-            for wic_name in config['wics']:
-                if wic_name and not self.router.slot[0].wics[wic_number]:
-                    # consider that all wics are in slot 0
-                    debug('Install ' + wic_name + ' in wic port ' + str(wic_number))
-                    self.router.installwic(wic_name, 0, wic_number)
-                wic_number += 1
+        try:
+            # configure wics if available
+            if config['wics']:
+                wic_number = 0
+                for wic_name in config['wics']:
+                    if wic_name and not self.router.slot[0].wics[wic_number]:
+                        # consider that all wics are in slot 0
+                        debug('Install ' + wic_name + ' in wic port ' + str(wic_number))
+                        self.router.installwic(wic_name, 0, wic_number)
+                    elif wic_name and self.router.slot[0].wics[wic_number] != wic_name:
+                        self.router.uninstallwic(wic_number)
+                        debug('Re-Install ' + wic_name + ' in wic port ' + str(wic_number))
+                        self.router.installwic(wic_name, 0, wic_number)
+                    elif not wic_name and self.router.slot[0].wics[wic_number]:
+                        self.router.uninstallwic(wic_number)
+                    wic_number += 1
+        except lib.DynamipsError, msg:
+            QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("IOSRouter", "Dynamips error"),  unicode(msg))
 
         self.local_config = config.copy()
         self.local_config['slots'] = list(config['slots'])
@@ -321,7 +347,7 @@ class IOSRouter(AbstractNode):
             if module and module.adapter != 'NM-16ESW':
                 interfaces = module.interfaces
                 if len(interfaces):
-                    type= interfaces.keys()[0]
+                    type = interfaces.keys()[0]
                     found = False
                     for port in interfaces[type].values():
                         if self.router.model_string in SLOTLESS_MODELS:
@@ -334,7 +360,21 @@ class IOSRouter(AbstractNode):
                     if found == False:
                         self.clean_slot(module)
 
-        # try to automatically asign a WIC ...
+        # try to find an empty interface in an occupied slot
+        for module in self.router.slot:
+            if module and module.adapter != 'NM-16ESW':
+                interfaces = module.interfaces
+                for interface_type in interfaces.keys():
+                    if interface_type == link_type:
+                        for port in interfaces[link_type].keys():
+                            if self.router.model_string in SLOTLESS_MODELS:
+                                interface_name = interface_type + str(port)
+                            else:
+                                interface_name = interface_type + str(module.slot) + '/' + str(port)
+                            if interface_name not in connected_interfaces:
+                                return (interface_name)
+
+        # try to automatically assign a WIC ...
         if self.local_config['wics']:
             wic_number = 0
             new_wic = None
@@ -352,7 +392,7 @@ class IOSRouter(AbstractNode):
                 debug('Install ' + new_wic + ' in wic port ' + str(wic_number))
                 self.router.installwic(new_wic, 0, wic_number)
 
-        # try to find an empty interface in an occupied slot
+        # try again to find an empty interface in an occupied slot
         for module in self.router.slot:
             if module and module.adapter != 'NM-16ESW':
                 interfaces = module.interfaces
@@ -452,22 +492,7 @@ class IOSRouter(AbstractNode):
         if devdefaults[model].has_key('jitsharing'):
             if devdefaults[model]['jitsharing']:
                 if self.dynagen.jitshareddevices.has_key(self.hostname):
-                    new_jit_group_created = globals.GApp.dynagen.jitsharing()
-                    # basename doesn't work on Unix with Windows paths, so let's use this little trick
-                    image = self.config['image']
-                    if not sys.platform.startswith('win') and image[1] == ":":
-                        image = image[2:]
-                        image = image.replace("\\", "/")
-                    imagename = os.path.basename(image)
-                    if router.dynamips.jitsharing_groups.has_key(imagename):
-                        router.jitsharing_group = router.dynamips.jitsharing_groups[imagename]
-                        if new_jit_group_created:
-                            for device in router.dynamips.devices:
-                                if device.jitsharing_group != None and router.jitsharing_group == device.jitsharing_group and device.name != router.name:
-                                    for node in globals.GApp.topology.nodes.values():
-                                        if node.hostname == device.name:
-                                            node.updateToolTips()
-                                            break
+                    globals.GApp.dynagen.jitsharing()
 
         self.dynagen.update_running_config()
         self.running_config = self.dynagen.running_config[self.d][self.r]
@@ -478,6 +503,12 @@ class IOSRouter(AbstractNode):
         """ Used when changing the hostname
         """
 
+        old_hostname = self.hostname
+        old_console = None
+        old_aux = None
+        if self.router:
+            old_console = self.router.console
+            old_aux = self.router.aux
         links = self.getEdgeList().copy()
         for link in links:
             globals.GApp.topology.deleteLink(link)
@@ -493,6 +524,10 @@ class IOSRouter(AbstractNode):
         self.set_hostname(new_hostname)
         try:
             self.create_router()
+            if old_console:
+                self.router.console = old_console
+            if old_aux:
+                self.router.aux = old_aux
         except lib.DynamipsError, msg:
             QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("IOSRouter", "Dynamips error"),  unicode(msg))
             self.delete_router()
@@ -501,6 +536,18 @@ class IOSRouter(AbstractNode):
         self.set_config(self.local_config)
         for link in links:
             globals.GApp.topology.addLink(link.source.id, link.srcIf, link.dest.id, link.destIf)
+            
+        # Update base config
+        try:
+            config = base64.decodestring(self.router.config_b64)
+            if config:
+                old_hostname
+                config = config.replace('\r', "")
+                config = '!\n' + config.replace(old_hostname, new_hostname)
+                encoded = ("").join(base64.encodestring(config).split())
+                self.router.config_b64 = encoded
+        except:
+            debug("Cannot change base config")
 
     def configNode(self):
         """ Node configuration
@@ -527,9 +574,12 @@ class IOSRouter(AbstractNode):
             module: object
         """
 
-        if module.can_be_removed():
-            module.remove()
-            self.router.slot[module.slot] = None
+        try:
+            if module.can_be_removed():
+                module.remove()
+                self.router.slot[module.slot] = None
+        except lib.DynamipsError, msg:
+            QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("IOSRouter", "Dynamips error"),  unicode(msg))
 
     def getInterfaces(self):
         """ Returns all the router interfaces
@@ -589,6 +639,7 @@ class IOSRouter(AbstractNode):
         if self.router.state != 'running':
             return
         self.stopNode(progress)
+        time.sleep(1)
         self.startNode(progress)
 
     def suspendNode(self, progress=False):
@@ -611,7 +662,26 @@ class IOSRouter(AbstractNode):
         """
 
         if self.router and self.router.state == 'running' and self.router.console:
-            console.connect(self.hypervisor.host,  self.router.console,  self.hostname)
+            console.connect(self.hypervisor.host, self.router.console, self.hostname)
+            
+    def aux(self):
+        """ Start a telnet console and connect it to this router's AUX port
+        """
+        if not self.router.aux:
+            print translate("IOSRouter", "AUX port not available for this router model or base AUX port is set to 0 in preferences")
+            return
+
+        if self.router and self.router.state == 'running':
+            console.connect(self.hypervisor.host, self.router.aux, self.hostname)
+    
+    def isStarted(self):
+        """ Returns True if this router is started
+        """
+
+        if self.router and self.router.state == 'running':
+            return True
+        else:
+            return False
 
     def mousePressEvent(self, event):
         """ Call when the node is clicked
