@@ -29,25 +29,30 @@ class ProjectDialog(QtGui.QDialog, Ui_NewProject):
     """ ProjectDialog class
     """
 
-    def __init__(self, projectFile=None, projectWorkdir=None, projectConfigs=None):
+    def __init__(self, projectFile=None, projectWorkdir=None, projectConfigs=None, newProject=False):
 
         QtGui.QDialog.__init__(self)
         self.setupUi(self)
         self.connect(self.NewProject_browser, QtCore.SIGNAL('clicked()'), self.__setProjectDir)
         self.connect(self.pushButtonOpenProject, QtCore.SIGNAL('clicked()'), self.__openProject)
         self.connect(self.ProjectName, QtCore.SIGNAL('textEdited(const QString &)'), self.__projectNameEdited)
-        
-        if projectFile:
-            self.ProjectName.setText(os.path.basename(projectFile).replace('.net', ''))
-            self.ProjectPath.setText(projectFile)
-        if projectWorkdir:
-            self.checkBox_WorkdirFiles.setCheckState(QtCore.Qt.Checked)
-        else:
-            self.checkBox_WorkdirFiles.setCheckState(QtCore.Qt.Unchecked)
-        if projectConfigs:
-            self.checkBox_ConfigFiles.setCheckState(QtCore.Qt.Checked)
-        else:
-            self.checkBox_ConfigFiles.setCheckState(QtCore.Qt.Unchecked)
+                   
+        if newProject == False:
+
+            if projectFile:
+                projectPath = os.path.dirname(projectFile)
+                projectName = os.path.basename(projectPath)
+                self.ProjectName.setText(projectName)
+                self.ProjectPath.setText(projectPath)
+
+            if projectWorkdir:
+                self.checkBox_WorkdirFiles.setCheckState(QtCore.Qt.Checked)
+            else:
+                self.checkBox_WorkdirFiles.setCheckState(QtCore.Qt.Unchecked)
+            if projectConfigs:
+                self.checkBox_ConfigFiles.setCheckState(QtCore.Qt.Checked)
+            else:
+                self.checkBox_ConfigFiles.setCheckState(QtCore.Qt.Unchecked)
 
     def __setProjectDir(self):
         """ Open a file dialog for choosing the location of the project directory
@@ -59,9 +64,9 @@ class ProjectDialog(QtGui.QDialog, Ui_NewProject):
         if path:
             path = os.path.normpath(path)
             if os.path.realpath(path) != os.path.realpath(globals.GApp.systconf['general'].project_path):
-                self.ProjectPath.setText(path + os.sep + self.ProjectName.text() + os.sep + self.ProjectName.text() + '.net')
+                self.ProjectPath.setText(path + os.sep + self.ProjectName.text())
             else:
-                self.ProjectPath.setText(path + os.sep + self.ProjectName.text() + '.net')
+                self.ProjectPath.setText(path)
 
     def __projectNameEdited(self, text):
         """ Propose a project directory when changing the project name
@@ -69,19 +74,18 @@ class ProjectDialog(QtGui.QDialog, Ui_NewProject):
         
         self.ProjectPath.clear()
         if text and globals.GApp.systconf['general'].project_path:
-            self.ProjectPath.setText(os.path.normpath(globals.GApp.systconf['general'].project_path) + os.sep + text + '.net')
+            self.ProjectPath.setText(os.path.normpath(globals.GApp.systconf['general'].project_path) + os.sep + text)
         elif text:
-            self.ProjectPath.setText(os.path.curdir + os.sep + text + os.sep + text + '.net')
+            self.ProjectPath.setText(os.path.curdir + os.sep + text)
 
     def saveProjectSettings(self):
         """ Save project settings
         """
 
         projectName = unicode(self.ProjectName.text())
-        projectPath = os.path.normpath(unicode(self.ProjectPath.text()))
-        projectDir = os.path.dirname(projectPath)
+        projectDir = os.path.normpath(unicode(self.ProjectPath.text()))
 
-        if not projectName or not projectPath:
+        if not projectName or not projectDir:
             return (None, None, None)
 
         if not os.path.exists(projectDir):
@@ -91,16 +95,17 @@ class ProjectDialog(QtGui.QDialog, Ui_NewProject):
                 QtGui.QMessageBox.critical(self, translate('ProjectDialog', 'Project Directory'), unicode(translate("Workspace", "Cannot create directory %s: %s")) % (projectDir, e.strerror))
                 return (None, None, None)
 
-        projectFile = projectPath
+        projectFile = projectDir + os.sep + 'topology.net'
+
         if os.environ.has_key("HOME"):
             projectFile = projectFile.replace('$HOME', os.environ["HOME"])
 
         if self.checkBox_WorkdirFiles.checkState() == QtCore.Qt.Checked:
-            projectWorkdir = os.path.normpath(projectDir + os.sep + projectName + '_working')
+            projectWorkdir = os.path.normpath(projectDir + os.sep + 'working')
         else:
             projectWorkdir = None
         if self.checkBox_ConfigFiles.checkState() == QtCore.Qt.Checked:
-            projectConfigs = os.path.normpath(projectDir + os.sep + projectName + '_configs')
+            projectConfigs = os.path.normpath(projectDir + os.sep + 'configs')
         else:
             projectConfigs = None
         return (projectFile, projectWorkdir, projectConfigs)
