@@ -28,6 +28,9 @@ from GNS3.Utils import translate, debug
 from GNS3.Annotation import Annotation
 from GNS3.ShapeItem import AbstractShapeItem, Rectangle, Ellipse
 from GNS3.StyleDialog import StyleDialog
+from GNS3.MACTableDialog import MACTableDialog
+from GNS3.SymbolDialog import SymbolDialog
+from GNS3.IDLEPCDialog import IDLEPCDialog
 from GNS3.Pixmap import Pixmap
 from GNS3.NodeConfigurator import NodeConfigurator
 from GNS3.Node.AbstractNode import AbstractNode
@@ -64,6 +67,9 @@ class Scene(QtGui.QGraphicsView):
         self.newedge = None
         self.resetAddingLink()
         self.reloadRenderers()
+        
+        self.sceneDragging = False
+        self.lastMousePos = None 
 
     def reloadRenderers(self):
         """ Load all needed renderers
@@ -131,6 +137,25 @@ class Scene(QtGui.QGraphicsView):
             self.connect(changeHypervisor, QtCore.SIGNAL('triggered()'), self.slotChangeHypervisor)
             
             menu.addAction(changeHypervisor)
+            
+        instances = map(lambda item: isinstance(item, ETHSW), items)
+        if True in instances:
+            
+            # Action: MAC Table
+            MACTableAct = QtGui.QAction(translate('Scene', 'MAC Address Table'), menu)
+            MACTableAct.setIcon(QtGui.QIcon(':/icons/inspect.svg'))
+            self.connect(MACTableAct, QtCore.SIGNAL('triggered()'), self.slotMACTable)
+
+            menu.addAction(MACTableAct)
+            
+        instances = map(lambda item: isinstance(item, AbstractNode), items)
+        if True in instances:
+
+            # Action: Change symbol
+            changeSymbol = QtGui.QAction(translate('Scene', 'Change Symbol'), menu)
+            changeSymbol.setIcon(QtGui.QIcon(':/icons/node_conception.svg'))
+            self.connect(changeSymbol, QtCore.SIGNAL('triggered()'), self.slotchangeSymbol)        
+            menu.addAction(changeSymbol)            
 
         instances = map(lambda item: isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice), items)
         if True in instances:
@@ -139,7 +164,7 @@ class Scene(QtGui.QGraphicsView):
             consolePortAct = QtGui.QAction(translate('Scene', 'Change console port'), menu)
             consolePortAct.setIcon(QtGui.QIcon(':/icons/console_port.svg'))
             self.connect(consolePortAct, QtCore.SIGNAL('triggered()'), self.slotChangeConsolePort)
-
+            
             # Action: Console (Connect to the node console)
             consoleAct = QtGui.QAction(translate('Scene', 'Console'), menu)
             consoleAct.setIcon(QtGui.QIcon(':/icons/console.svg'))
@@ -154,15 +179,31 @@ class Scene(QtGui.QGraphicsView):
             stopAct = QtGui.QAction(translate('Scene', 'Stop'), menu)
             stopAct.setIcon(QtGui.QIcon(':/icons/stop.svg'))
             self.connect(stopAct, QtCore.SIGNAL('triggered()'), self.slotStopNode)
+            
+            # Action: Reload (stop and start IOS on hypervisor)
+            reloadAct = QtGui.QAction(translate('Scene', 'Reload'), menu)
+            reloadAct.setIcon(QtGui.QIcon(':/icons/reload.svg'))
+            self.connect(reloadAct, QtCore.SIGNAL('triggered()'), self.slotReloadNode)
 
             menu.addAction(consolePortAct)
             menu.addAction(consoleAct)
             menu.addAction(startAct)
             menu.addAction(stopAct)
+            menu.addAction(reloadAct)
 
         instances = map(lambda item: isinstance(item, IOSRouter), items)
         if True in instances:
 
+            # Action: Change the aux port
+            auxPortAct = QtGui.QAction(translate('Scene', 'Change AUX port'), menu)
+            auxPortAct.setIcon(QtGui.QIcon(':/icons/console_port.svg'))
+            self.connect(auxPortAct, QtCore.SIGNAL('triggered()'), self.slotChangeAUXPort)
+
+            # Action: Console (Connect to the node console)
+            AuxAct = QtGui.QAction(translate('Scene', 'Console to AUX port'), menu)
+            AuxAct.setIcon(QtGui.QIcon(':/icons/aux.svg'))
+            self.connect(AuxAct, QtCore.SIGNAL('triggered()'), self.slotAuxConsole)
+
             # Action: Calculate IDLE PC
             idlepcAct = QtGui.QAction(translate('Scene', 'Idle PC'), menu)
             idlepcAct.setIcon(QtGui.QIcon(':/icons/calculate.svg'))
@@ -177,14 +218,10 @@ class Scene(QtGui.QGraphicsView):
             suspendAct = QtGui.QAction(translate('Scene', 'Suspend'), menu)
             suspendAct.setIcon(QtGui.QIcon(':/icons/pause.svg'))
             self.connect(suspendAct, QtCore.SIGNAL('triggered()'), self.slotSuspendNode)
-            
-            # Action: Reload (stop and start IOS on hypervisor)
-            reloadAct = QtGui.QAction(translate('Scene', 'Reload'), menu)
-            reloadAct.setIcon(QtGui.QIcon(':/icons/reload.svg'))
-            self.connect(reloadAct, QtCore.SIGNAL('triggered()'), self.slotReloadNode)
 
             menu.addAction(suspendAct)
-            menu.addAction(reloadAct)
+            menu.addAction(auxPortAct)
+            menu.addAction(AuxAct)
             menu.addAction(idlepcAct)
             menu.addAction(StartupConfigAct)
 
@@ -198,6 +235,13 @@ class Scene(QtGui.QGraphicsView):
 
             menu.addAction(styleAct)
             
+            # Action: Duplicate
+            duplicateAct = QtGui.QAction(translate('Scene', 'Duplicate'), menu)
+            duplicateAct.setIcon(QtGui.QIcon(':/icons/new.svg'))
+            self.connect(duplicateAct, QtCore.SIGNAL('triggered()'), self.slotDuplicate)
+
+            menu.addAction(duplicateAct)
+            
         # Action: Delete (Delete the node)
         deleteAct = QtGui.QAction(translate('Scene', 'Delete'), menu)
         deleteAct.setIcon(QtGui.QIcon(':/icons/delete.svg'))
@@ -213,10 +257,25 @@ class Scene(QtGui.QGraphicsView):
         raiseZvalueAct = QtGui.QAction(translate('Scene', 'Raise one step'), menu)
         raiseZvalueAct.setIcon(QtGui.QIcon(':/icons/raise_z_value.svg'))
         self.connect(raiseZvalueAct, QtCore.SIGNAL('triggered()'), self.slotraiseZValue)
-
+        
         menu.addAction(raiseZvalueAct)
         menu.addAction(lowerZvalueAct)
 
+        items = self.__topology.selectedItems()
+        if len(items) > 1:
+       
+            # Action: Align horizontally
+            hozAlignAct = QtGui.QAction(translate('Scene', 'Align horizontally'), menu)
+            hozAlignAct.setIcon(QtGui.QIcon(':/icons/horizontally.svg'))
+            self.connect(hozAlignAct, QtCore.SIGNAL('triggered()'), self.slotHozAlignment)
+            menu.addAction(hozAlignAct)
+            
+            # Action: Align vertically
+            vertAlignAct = QtGui.QAction(translate('Scene', 'Align vertically'), menu)
+            vertAlignAct.setIcon(QtGui.QIcon(':/icons/vertically.svg'))
+            self.connect(vertAlignAct, QtCore.SIGNAL('triggered()'), self.slotVertAlignment)
+            menu.addAction(vertAlignAct)
+
         menu.exec_(QtGui.QCursor.pos())
 
         # force the deletion of the children
@@ -235,11 +294,37 @@ class Scene(QtGui.QGraphicsView):
 
         splash = QtGui.QSplashScreen(QtGui.QPixmap(":images/logo_gns3_splash.png"))
         splash.show()
-        splash.showMessage(translate("Scene", "Please wait while calculating an IDLE PC"))
+        splash.showMessage(translate("Scene", "Please wait while calculating IDLE PC values"))
         globals.GApp.processEvents(QtCore.QEventLoop.AllEvents | QtCore.QEventLoop.WaitForMoreEvents, 1000)
         result = globals.GApp.dynagen.devices[router.hostname].idleprop(lib.IDLEPROPGET)
         return result
 
+    def slotMACTable(self):
+        """ Show Ethernet Switch MAC Address Table
+        """
+
+        for item in self.__topology.selectedItems():
+            if isinstance(item, ETHSW):
+                table = MACTableDialog(item)
+                table.show()
+                table.exec_()
+
+    def slotHozAlignment(self):
+        """ Horizontally align items
+        """
+        
+        hozPos = self.__topology.selectedItems()[0].y()
+        for item in self.__topology.selectedItems():
+            item.setPos(item.x(), hozPos)
+            
+    def slotVertAlignment(self):
+        """ Vertically align items
+        """
+        
+        vertPos = self.__topology.selectedItems()[0].x()
+        for item in self.__topology.selectedItems():
+            item.setPos(vertPos, item.y())
+
     def slotStyle(self):
         """ Change the style of an annotation or a shape item
         """
@@ -263,7 +348,7 @@ class Scene(QtGui.QGraphicsView):
             for item in self.__topology.selectedItems():
                 if isinstance(item, Annotation):
                     command = undo.NewAnnotationStyle(item, style.color, style.font, style.rotation)
-                    item.autoGenerated = False
+                    #item.autoGenerated = False
                     self.__topology.undoStack.push(command)
                 elif isinstance(item, AbstractShapeItem):
                     pen = QtGui.QPen(style.borderColor, style.borderWidth, style.borderStyle, QtCore.Qt.RoundCap, QtCore.Qt.RoundJoin)
@@ -271,6 +356,40 @@ class Scene(QtGui.QGraphicsView):
                     command = undo.NewItemStyle(item, pen, brush, style.rotation)
                     self.__topology.undoStack.push(command)
 
+    def slotDuplicate(self):
+        """ Duplicate an item
+        """
+        
+        for item in self.__topology.selectedItems():
+            if isinstance(item, Annotation):
+                dupnote = Annotation()
+                dupnote.setPos(item.x(), item.y() - 20)
+                dupnote.setPlainText(item.toPlainText())
+                dupnote.setDefaultTextColor(item.defaultTextColor())
+                dupnote.setFont(item.font())
+                dupnote.rotate(item.rotation)
+                dupnote.rotation = item.rotation
+                dupnote.setZValue(item.zValue())
+                command = undo.AddItem(self.__topology, dupnote, translate("Scene", "annotation"))
+                self.__topology.undoStack.push(command)
+            if isinstance(item, AbstractShapeItem):
+                pos = QtCore.QPointF(item.x() - 20, item.y() - 20)
+                rect = item.rect()
+                if isinstance(item, Rectangle):
+                    dupshape = Rectangle(pos, QtCore.QSizeF(rect.width(), rect.height()))
+                else:
+                    dupshape = Ellipse(pos, QtCore.QSizeF(rect.width(), rect.height()))
+                dupshape.setPen(item.pen())
+                dupshape.setBrush(item.brush())
+                dupshape.rotate(item.rotation)
+                dupshape.rotation = item.rotation
+                dupshape.setZValue(item.zValue())
+                if isinstance(dupshape, Rectangle):
+                    command = undo.AddItem(self.__topology, dupshape, translate("Scene", "rectangle"))
+                else:
+                    command = undo.AddItem(self.__topology, dupshape, translate("Scene", "ellipse"))
+                self.__topology.undoStack.push(command)
+
     def slotIdlepc(self):
         """ Compute an IDLE PC
         """
@@ -295,59 +414,39 @@ class Scene(QtGui.QGraphicsView):
                     result = globals.GApp.dynagen.devices[router.hostname].idleprop(lib.IDLEPROPSHOW)
             else:
                 result = self.calculateIDLEPC(router)
-
-            # remove the '100-OK' line
-            result.pop()
-
-            idles = {}
-            options = []
-            i = 1
-            for line in result:
-                (value, count) = line.split()[1:]
-
-                # Flag potentially "best" idlepc values (between 50 and 60)
-                iCount = int(count[1:-1])
-                if 50 < iCount < 60:
-                    flag = '*'
-                else:
-                    flag = ' '
-
-                option = "%s %i: %s %s" % (flag, i, value, count)
-                options.append(option)
-                idles[i] = value
-                i += 1
-
-            if len(idles) == 0:
-                QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("Scene", "IDLE PC"),  translate("Scene", "No idlepc values found"))
-                return
-            (selection,  ok) = QtGui.QInputDialog.getItem(globals.GApp.mainWindow, translate("Scene", "IDLE PC"),
-                                                        translate("Scene", "Potentially better idlepc values marked with '*'"), options, 0, False)
-            if ok:
-                selection = str(selection).split(':')[0].strip('* ')
-                index = int(selection)
-                for node in globals.GApp.topology.nodes.values():
-                    if isinstance(node, IOSRouter) and node.hostname == router.hostname:
-                        dyn_router = node.get_dynagen_device()
-                        if globals.GApp.iosimages.has_key(dyn_router.dynamips.host + ':' + dyn_router.image):
-                            image = globals.GApp.iosimages[dyn_router.dynamips.host + ':' + dyn_router.image]
-                            debug("Register IDLE PC " + idles[index] + " for image " + image.filename)
-                            image.idlepc =  idles[index]
-                            # Apply idle pc to devices with the same IOS image
-                            for device in globals.GApp.topology.nodes.values():
-                                if isinstance(device, IOSRouter) and device.config['image'] == image.filename:
-                                    debug("Apply IDLE PC " + idles[index] + " to " + device.hostname)
-                                    device.get_dynagen_device().idlepc = idles[index]
-                                    config = device.get_config()
-                                    config['idlepc'] = idles[index]
-                                    device.set_config(config)
-                                    device.setCustomToolTip()
-                            break
-                QtGui.QMessageBox.information(globals.GApp.mainWindow, translate("Scene", "IDLE PC"),
-                                              unicode(translate("Scene", "Applied idlepc value %s to %s")) % (idles[index], router.hostname))
         except lib.DynamipsError, msg:
             QtGui.QMessageBox.critical(self, translate("Scene", "Dynamips error"),  unicode(msg))
             return
 
+        # remove the '100-OK' line
+        result.pop()
+
+        idles = {}
+        options = []
+        i = 1
+        for line in result:
+            (value, count) = line.split()[1:]
+
+            # Flag potentially "best" idlepc values (between 50 and 60)
+            iCount = int(count[1:-1])
+            if 50 < iCount < 60:
+                flag = '*'
+            else:
+                flag = ' '
+
+            option = "%s %i: %s %s" % (flag, i, value, count)
+            options.append(option)
+            idles[i] = value
+            i += 1
+
+        if len(idles) == 0:
+            QtGui.QMessageBox.critical(globals.GApp.mainWindow, translate("Scene", "IDLE PC"),  translate("Scene", "No idlepc values found"))
+            return
+
+        idlepcdiag = IDLEPCDialog(router, idles, options)
+        idlepcdiag.show()
+        idlepcdiag.exec_()
+
     def slotConfigNode(self):
         """ Called to configure nodes
         """
@@ -391,6 +490,18 @@ class Scene(QtGui.QGraphicsView):
         """ Called to delete nodes
         """
 
+        count = 0
+        for item in self.__topology.selectedItems():
+            if not isinstance(item, Annotation) and not isinstance(item, Pixmap) and not isinstance(item, AbstractShapeItem):
+                count += 1
+        
+        if count > 1:
+            reply = QtGui.QMessageBox.question(self, translate("Scene", "Message"), translate("Scene", "Do you really want to delete these nodes?"), 
+                                            QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+
+            if reply == QtGui.QMessageBox.No:
+                return
+
         ok_to_delete_node = True
         for item in self.__topology.selectedItems():
             if not isinstance(item, Annotation) and not isinstance(item, Pixmap) and not isinstance(item, AbstractShapeItem):
@@ -427,6 +538,19 @@ class Scene(QtGui.QGraphicsView):
             zvalue = item.zValue()
             command = undo.NewZValue(item, zvalue + 1)
             self.__topology.undoStack.push(command)
+            
+    def slotchangeSymbol(self):
+        """ Change a device's symbol
+        """
+        
+        item_list = []
+        for item in self.__topology.selectedItems():
+            if isinstance(item, AbstractNode):
+                item_list.append(item)
+        if len(item_list):
+            dialog = SymbolDialog(item_list)
+            dialog.show()
+            dialog.exec_()
 
     def slotConsole(self):
         """ Slot called to launch a console on the selected items
@@ -436,6 +560,14 @@ class Scene(QtGui.QGraphicsView):
             if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
                 item.console()
                 
+    def slotAuxConsole(self):
+        """ Slot called to launch a console to AUX on the selected items
+        """
+
+        for item in self.__topology.selectedItems():
+            if isinstance(item, IOSRouter):
+                item.aux()
+                
     def slotChangeConsolePort(self):
         """ Slot called to change the console port
         """
@@ -443,6 +575,14 @@ class Scene(QtGui.QGraphicsView):
         for item in self.__topology.selectedItems():
             if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
                 item.changeConsolePort()
+                
+    def slotChangeAUXPort(self):
+        """ Slot called to change the aux port
+        """
+
+        for item in self.__topology.selectedItems():
+            if isinstance(item, IOSRouter):
+                item.changeAUXPort()
 
     def slotStartupConfig(self):
         """ Slot called to change the startup-config
@@ -463,7 +603,19 @@ class Scene(QtGui.QGraphicsView):
     def slotStopNode(self):
         """ Slot called to stop the selected items
         """
+     
+        count = 0
+        for item in self.__topology.selectedItems():
+            if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
+                count += 1
 
+        if count > 1:
+            reply = QtGui.QMessageBox.question(self, translate("Scene", "Message"), translate("Scene", "Do you really want to stop these devices?"), 
+                                            QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+
+            if reply == QtGui.QMessageBox.No:
+                return
+     
         for item in self.__topology.selectedItems():
             if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
                 item.stopNode()
@@ -480,8 +632,20 @@ class Scene(QtGui.QGraphicsView):
         """ Slot called to reload the selected items
         """
 
+        count = 0
         for item in self.__topology.selectedItems():
-            if  isinstance(item, IOSRouter):
+            if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
+                count += 1
+
+        if count > 1:
+            reply = QtGui.QMessageBox.question(self, translate("Scene", "Message"), translate("Scene", "Do you really want to reload these devices?"), 
+                                            QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+
+            if reply == QtGui.QMessageBox.No:
+                return
+
+        for item in self.__topology.selectedItems():
+            if isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice):
                 item.reloadNode()
                 
     def getSourceNode(self):
@@ -565,9 +729,11 @@ class Scene(QtGui.QGraphicsView):
         self.scale(scale_factor, scale_factor)
 
     def wheelEvent(self, event):
-        """ Zoom with the mouse wheel
+        """ Zoom or scroll with the mouse wheel
         """
-        self.scaleView(pow(2.0, -event.delta() / 240.0))
+
+        if event.orientation() == QtCore.Qt.Vertical:
+            self.scaleView(pow(2.0, event.delta() / 240.0))
 
     def keyPressEvent(self, event):
         """ key press handler
@@ -651,16 +817,29 @@ class Scene(QtGui.QGraphicsView):
             item_type = type(item)
             if item_type == Ethernet or item_type == Serial:
                 show = False
+
+        # This statement checks to see if either the middle mouse is pressed
+        # or a combination of the right and left mouse buttons is pressed to start dragging the view
+        if show and event.buttons() == (QtCore.Qt.LeftButton | QtCore.Qt.RightButton) or event.buttons() & QtCore.Qt.MidButton:
+            self.lastMousePos = self.mapFromGlobal(event.globalPos())
+            self.sceneDragging = True
+            globals.GApp.scene.setCursor(QtCore.Qt.ClosedHandCursor)
+            return 
                 
         if show and event.modifiers() & QtCore.Qt.ShiftModifier and event.button() == QtCore.Qt.LeftButton and item and not globals.addingLinkFlag:
             item.setSelected(True)
         elif show and event.button() == QtCore.Qt.RightButton and not globals.addingLinkFlag:
             if item:
-                if not event.modifiers() & QtCore.Qt.ShiftModifier:
-                    for it in globals.GApp.topology.items():
-                        it.setSelected(False)
-                item.setSelected(True)
-                self.showContextualMenu()
+                #Prevent right clicking on a selected item from de-selecting all other items
+                if not item.isSelected():
+                    if not event.modifiers() & QtCore.Qt.ShiftModifier:
+                        for it in self.__topology.items():
+                            it.setSelected(False)
+                    item.setSelected(True)
+                    self.showContextualMenu()
+                else:
+                    self.showContextualMenu()
+            # When more than one item is selected display the contextual menu even if mouse is not above an item
             elif len(self.__topology.selectedItems()) > 1:
                 self.showContextualMenu()
         elif event.button() == QtCore.Qt.LeftButton and globals.addingNote:
@@ -694,18 +873,44 @@ class Scene(QtGui.QGraphicsView):
         else:
             QtGui.QGraphicsView.mousePressEvent(self, event)
 
+    def mouseReleaseEvent(self, event):
+        """ If The Left and Right mouse buttons are not still pressed TOGETHER and neither is the middle button
+            this means the user is no longer trying to drag the scene
+        """
+        
+        if self.sceneDragging and not event.buttons() == (QtCore.Qt.LeftButton | QtCore.Qt.RightButton) and not event.buttons() & QtCore.Qt.MidButton:
+            self.sceneDragging = False
+            globals.GApp.scene.setCursor(QtCore.Qt.ArrowCursor)
+        else:   
+            QtGui.QGraphicsView.mouseReleaseEvent(self, event)
+
     def mouseDoubleClickEvent(self, event):
 
         item = self.itemAt(event.pos())
         if not globals.addingLinkFlag and isinstance(item, AbstractNode):
             item.setSelected(True)
-            self.slotConfigNode()
+            if (isinstance(item, IOSRouter) or isinstance(item, AnyEmuDevice)) and item.isStarted():
+                self.slotConsole()
+            else:
+                self.slotConfigNode()
         else:
             QtGui.QGraphicsView.mouseDoubleClickEvent(self, event)
 
     def mouseMoveEvent(self, event):
-
-        if (self.newedge):
+        """ This if statement event checks to see if the user is dragging the scene
+            if so it sets the value of the scene scroll bars based on the change between
+            the previous and current mouse position
+        """
+        
+        if self.sceneDragging:
+            mappedGlobalPos = self.mapFromGlobal(event.globalPos())
+            hBar = self.horizontalScrollBar()
+            vBar = self.verticalScrollBar()
+            delta = mappedGlobalPos - self.lastMousePos;
+            hBar.setValue(hBar.value() + (delta.x() if globals.GApp.isRightToLeft() else -delta.x()))
+            vBar.setValue(vBar.value() - delta.y())
+            self.lastMousePos = mappedGlobalPos
+        elif (self.newedge):
             self.newedge.setMousePoint(self.mapToScene(event.pos()))
             event.ignore()
         else:
