@@ -48,7 +48,7 @@ class UiConfig_PreferencesCapture(QtGui.QWidget, Ui_PreferencesCapture):
         # Defaults capture terminal command
         if self.conf.cap_cmd == '':
             if sys.platform.startswith('darwin'):
-                self.conf.cap_cmd = unicode("/sw/bin/wireshark %c")
+                self.conf.cap_cmd = unicode("/usr/bin/open -a /Applications/Wireshark.app %c")
             elif sys.platform.startswith('win'):
                 self.conf.cap_cmd = unicode("C:\Program Files\Wireshark\wireshark.exe %c")
             else:
@@ -56,9 +56,9 @@ class UiConfig_PreferencesCapture(QtGui.QWidget, Ui_PreferencesCapture):
 
         if self.conf.workdir == '':
             if os.environ.has_key("TEMP"):
-                self.conf.workdir = unicode(os.environ["TEMP"])
+                self.conf.workdir = unicode(os.environ["TEMP"], errors='replace')
             elif os.environ.has_key("TMP"):
-                self.conf.workdir = unicode(os.environ["TMP"])
+                self.conf.workdir = unicode(os.environ["TMP"], errors='replace')
             else:
                 self.conf.workdir = unicode('/tmp')
 
@@ -91,3 +91,9 @@ class UiConfig_PreferencesCapture(QtGui.QWidget, Ui_PreferencesCapture):
 
         if path:
             self.CaptureWorkingDirectory.setText(os.path.normpath(path))
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(globals.preferencesWindow, translate("Page_PreferencesCapture", "Capture directory"), translate("Page_PreferencesCapture", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
