@@ -71,6 +71,7 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
         self.dynamips_port.setValue(self.conf.port)
         self.dynamips_baseUDP.setValue(self.conf.baseUDP)
         self.dynamips_baseConsole.setValue(self.conf.baseConsole)
+        self.dynamips_baseAUX.setValue(self.conf.baseAUX)
         self.spinBoxMemoryLimit.setValue(self.conf.memory_limit)
         self.spinBoxUDPIncrementation.setValue(self.conf.udp_incrementation)
 
@@ -82,6 +83,10 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
             self.checkBoxHypervisorManagerImport.setCheckState(QtCore.Qt.Checked)
         else:
             self.checkBoxHypervisorManagerImport.setCheckState(QtCore.Qt.Unchecked)
+        if self.conf.allocateHypervisorPerIOS == True:
+            self.checkBoxAllocatePerIOS.setCheckState(QtCore.Qt.Checked)
+        else:
+            self.checkBoxAllocatePerIOS.setCheckState(QtCore.Qt.Unchecked)
         if self.conf.ghosting == True:
             self.checkBoxGhosting.setCheckState(QtCore.Qt.Checked)
         else:
@@ -112,6 +117,7 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
         self.conf.port = self.dynamips_port.value()
         self.conf.baseUDP = self.dynamips_baseUDP.value()
         self.conf.baseConsole = self.dynamips_baseConsole.value()
+        self.conf.baseAUX = self.dynamips_baseAUX.value()
         self.conf.memory_limit = self.spinBoxMemoryLimit.value()
         self.conf.udp_incrementation = self.spinBoxUDPIncrementation.value()
         if self.checkBoxClearWorkdir.checkState() == QtCore.Qt.Checked:
@@ -122,6 +128,10 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
             self.conf.import_use_HypervisorManager = True
         else:
             self.conf.import_use_HypervisorManager = False
+        if self.checkBoxAllocatePerIOS.checkState() == QtCore.Qt.Checked:
+            self.conf.allocateHypervisorPerIOS = True
+        else:
+            self.conf.allocateHypervisorPerIOS = False
         if self.checkBoxGhosting.checkState() == QtCore.Qt.Checked:
             self.conf.ghosting = True
         else:
@@ -163,8 +173,15 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
             if not testOpenFile(path):
                 QtGui.QMessageBox.critical(globals.preferencesWindow, 'Dynamips path', unicode(translate("UiConfig_PreferencesDynamips", "Can't open file: %s")) % path)
                 return
+
             self.dynamips_path.clear()
             self.dynamips_path.setText(os.path.normpath(path))
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(globals.preferencesWindow, translate("UiConfig_PreferencesDynamips", "Dynamips path"), translate("UiConfig_PreferencesDynamips", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
 
     def __setDynamipsWorkdir(self):
         """ Open a file dialog for choosing the location of local hypervisor
@@ -175,6 +192,12 @@ class UiConfig_PreferencesDynamips(QtGui.QWidget, Ui_PreferencesDynamips):
 
         if path:
             self.dynamips_workdir.setText(os.path.normpath(path))
+            
+            if sys.platform.startswith('win'):
+                try:
+                    path.encode('ascii')
+                except:
+                    QtGui.QMessageBox.warning(globals.preferencesWindow, translate("UiConfig_PreferencesDynamips", "Working directory"), translate("UiConfig_PreferencesDynamips", "The path you have selected should contains only ascii (English) characters. Dynamips (Cygwin DLL) doesn't support unicode on Windows!"))
 
     def __testDynamips(self):
         
