@@ -35,7 +35,7 @@ from GNS3.SnapshotDialog import SnapshotDialog
 from GNS3.Utils import debug, translate, fileBrowser
 from GNS3.Config.Preferences import PreferencesDialog
 from GNS3.Node.IOSRouter import IOSRouter
-from GNS3.Node.AnyEmuDevice import AnyEmuDevice
+from GNS3.Node.AnyEmuDevice import AnyEmuDevice, JunOS, IDS, QemuDevice
 from GNS3.Pixmap import Pixmap
 
 class Workspace(QMainWindow, Ui_MainWindow):
@@ -70,6 +70,9 @@ class Workspace(QMainWindow, Ui_MainWindow):
         # By default don't show interface names
         self.flg_showInterfaceNames = False
         
+        # By default show only saved interface names (after loading a topology)
+        self.flg_showOnlySavedInterfaceNames = False
+        
         # By default don't show layer positioning
         self.flg_showLayerPos = False
     
@@ -96,6 +99,10 @@ class Workspace(QMainWindow, Ui_MainWindow):
         # Class to display error/warning messages once
         self.errorMessage = QtGui.QErrorMessage(self)
         self.errorMessage.setMinimumSize(350, 200)
+        
+        # Auto save timer
+        self.timer = QtCore.QTimer()
+        QtCore.QObject.connect(self.timer, QtCore.SIGNAL("timeout()"), self.__action_Autosave)
 
     def __connectActions(self):
         """ Connect all needed pair (action, SIGNAL)
@@ -113,6 +120,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.connect(self.action_SelectAll, QtCore.SIGNAL('triggered()'), self.__action_SelectAll)
         self.connect(self.action_SelectNone, QtCore.SIGNAL('triggered()'), self.__action_SelectNone)
         self.connect(self.action_TelnetAll,  QtCore.SIGNAL('triggered()'), self.__action_TelnetAll)
+        self.connect(self.action_ConsoleAuxAll,  QtCore.SIGNAL('triggered()'), self.__action_ConsoleAuxAll)
         self.connect(self.action_StartAll,  QtCore.SIGNAL('triggered()'), self.__action_StartAll)
         self.connect(self.action_StopAll,  QtCore.SIGNAL('triggered()'), self.__action_StopAll)
         self.connect(self.action_SuspendAll,  QtCore.SIGNAL('triggered()'), self.__action_SuspendAll)
@@ -121,7 +129,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.connect(self.action_About,  QtCore.SIGNAL('triggered()'), self.__action_About)
         self.connect(self.action_AboutQt,  QtCore.SIGNAL('triggered()'), self.__action_AboutQt)
         self.connect(self.action_New,  QtCore.SIGNAL('triggered()'), self.__action_NewProject)
-        self.connect(self.action_EditProject,  QtCore.SIGNAL('triggered()'), self.__action_EditProject)
+        self.connect(self.action_SaveProjectAs,  QtCore.SIGNAL('triggered()'), self.__action_SaveProjectAs)
         self.connect(self.action_Open,  QtCore.SIGNAL('triggered()'), self.__action_OpenFile)
         self.connect(self.action_Save,  QtCore.SIGNAL('triggered()'), self.__action_Save)
         self.connect(self.action_SaveAs,  QtCore.SIGNAL('triggered()'), self.__action_SaveAs)
@@ -136,6 +144,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.connect(self.action_Undo, QtCore.SIGNAL('triggered()'), self.__action_Undo)
         self.connect(self.action_Redo, QtCore.SIGNAL('triggered()'), self.__action_Redo)
         self.connect(self.action_ShowLayers, QtCore.SIGNAL('triggered()'), self.__action_ShowLayers)
+        self.connect(self.action_ResetInterfaceLabels, QtCore.SIGNAL('triggered()'), self.__action_ResetInterfaceLabels)
         
     def __createMenus(self):
         """ Add own menu actions, and create new sub-menu
@@ -146,6 +155,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.subm.addAction(self.dockWidget_TopoSum.toggleViewAction())
         self.subm.addAction(self.dockWidget_Console.toggleViewAction())
         self.subm.addAction(self.dockWidget_UndoView.toggleViewAction())
+        self.subm.addAction(self.dockWidget_Capture.toggleViewAction())
         self.menu_View.addSeparator().setText(translate("Workspace", "Docks"))
         self.menu_View.addMenu(self.subm)
 
@@ -190,7 +200,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
             painter.end()
         else:
 
-            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Yes - Export all the workspace\nNo - Export only what I see"), 
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Yes - Take all the workspace\nNo - Take only what I see"), 
                                             QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
 
             if reply == QtGui.QMessageBox.Yes:
@@ -216,7 +226,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
                 rect = self.graphicsView.viewport().rect()
                 width = rect.width() + 10
                 height = rect.height() + 10
-    
+
             pixmap = QtGui.QPixmap(width, height)
             pixmap.fill(QtCore.Qt.white)
             painter = QtGui.QPainter(pixmap)
@@ -235,7 +245,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         filedialog = QtGui.QFileDialog(self)
         selected = QtCore.QString()
         exports = 'PNG File (*.png);;JPG File (*.jpeg *.jpg);;BMP File (*.bmp);;XPM File (*.xpm *.xbm);;PDF File (*.pdf)'
-        path = QtGui.QFileDialog.getSaveFileName(filedialog, 'Export', '.', exports, selected)
+        path = QtGui.QFileDialog.getSaveFileName(filedialog, 'Screenshot', '.', exports, selected)
         if not path:
             return
         path = unicode(path)
@@ -260,26 +270,17 @@ class Workspace(QMainWindow, Ui_MainWindow):
         except IOError, (errno, strerror):
             QtGui.QMessageBox.critical(self, translate("Workspace", "I/O Error"),  unicode(translate("Workspace", "I/O Error: %s")) % strerror)
 
-    def clear(self):
-        """ Clear all the workspace
+    def clear_workdir(self, projectWorkdir):
+        """ Delete useless working directory files
         """
 
-        globals.GApp.workspace.setWindowTitle("GNS3")
-        projectWorkdir = self.projectWorkdir
-        self.projectFile = None
-        self.projectWorkdir = None
-        self.projectConfigs = None
-        globals.GApp.topology.clear()
-        for item in globals.GApp.topology.items():
-            globals.GApp.topology.removeItem(item)
-            
         if globals.GApp.systconf['dynamips'].clean_workdir:
             # delete dynamips files
             dynamips_files = glob.glob(os.path.normpath(globals.GApp.systconf['dynamips'].workdir) + os.sep + "c[0-9][0-9][0-9][0-9]_*")
             dynamips_files += glob.glob(os.path.normpath(globals.GApp.systconf['dynamips'].workdir) + os.sep + "*ghost*")
             dynamips_files += glob.glob(os.path.normpath(globals.GApp.systconf['dynamips'].workdir) + os.sep + "*_lock")
             dynamips_files += glob.glob(os.path.normpath(globals.GApp.systconf['dynamips'].workdir) + os.sep + "*_log.txt")
-            
+
             if projectWorkdir:
                 # delete useless project files
                 dynamips_files += glob.glob(os.path.normpath(projectWorkdir) + os.sep + "*ghost*")
@@ -294,15 +295,48 @@ class Workspace(QMainWindow, Ui_MainWindow):
                     #print unicode(translate("Workspace", "Warning: Can't delete %s => %s")) % (file, e.strerror)
                     continue
 
+    def clear(self):
+        """ Clear all the workspace
+        """
+
+        globals.GApp.workspace.setWindowTitle("GNS3")
+        projectWorkdir = self.projectWorkdir
+        self.timer.stop()
+        self.projectFile = None
+        self.projectWorkdir = None
+        self.projectConfigs = None
+
+        globals.GApp.topology.clear()
+        for item in globals.GApp.topology.items():
+            globals.GApp.topology.removeItem(item)
+            
+        self.clear_workdir(projectWorkdir)
+        globals.GApp.mainWindow.capturesDock.refresh()
+
     def __action_Clear(self):
         """ Clear the topology
         """
 
-        reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Are you sure to clear the topology?"), 
-                                            QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        running_nodes = False
+        for node in globals.GApp.topology.nodes.itervalues():
+            if (isinstance(node, IOSRouter) or isinstance(node, AnyEmuDevice)) and node.get_dynagen_device().state == 'running':
+                running_nodes = True
 
-        if reply == QtGui.QMessageBox.Yes:
-            self.clear()
+        if len(globals.GApp.topology.nodes) and globals.GApp.topology.changed == True:
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to save the current topology?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No, QtGui.QMessageBox.Cancel)
+            if reply == QtGui.QMessageBox.Yes:
+                self.__action_Save()
+            elif reply == QtGui.QMessageBox.Cancel:
+                return
+
+        elif running_nodes:
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "You have running nodes and you may loose your configurations inside them, would you like to continue anyway?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            if reply == QtGui.QMessageBox.No:
+                return
+
+        self.clear()
 
     def __action_Config(self):
         """ Choose between extracting or importing configs
@@ -350,7 +384,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
                     try:
                         f = open(path + os.sep + file, 'r')
                         config = f.read()
-                        config = '\n!\n' + config
+                        config = '!\n' + config
                         f.close()
                         # Encodestring puts in a bunch of newlines. Split them out then join them back together
                         encoded = ("").join(base64.encodestring(config).split())
@@ -367,6 +401,8 @@ class Workspace(QMainWindow, Ui_MainWindow):
                     except (lib.DynamipsErrorHandled,  socket.error):
                         QtGui.QMessageBox.critical(self, unicode(translate("Workspace", "%s: Dynamips error")) % device, translate("Workspace", "Connection lost"))
 
+        self.__action_Save(auto=True)
+
     def __action_AddNote(self):
         """ Add a note to the scene
         """
@@ -546,6 +582,13 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """
         
         if self.flg_showInterfaceNames == False:
+
+            if not len(globals.interfaceLabels) and self.flg_showOnlySavedInterfaceNames:
+                reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Reset saved interface labels?"), 
+                QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+                if reply == QtGui.QMessageBox.Yes:
+                    self.flg_showOnlySavedInterfaceNames = False
+
             self.flg_showInterfaceNames = True
             self.action_ShowinterfaceNames.setText(translate('Workspace', 'Hide interface names'))
             for link in globals.GApp.topology.links:
@@ -555,7 +598,23 @@ class Workspace(QMainWindow, Ui_MainWindow):
             self.action_ShowinterfaceNames.setText(translate('Workspace', 'Show interface names'))
             for link in globals.GApp.topology.links:
                 link.adjust()
+                
+    def __action_ResetInterfaceLabels(self):
+        """ Reset saved Interface Labels
+        """
         
+        if self.flg_showInterfaceNames:
+            QtGui.QMessageBox.warning(self, translate("Workspace", "Interface labels"), translate("Workspace", "Please hide the interface names before using this option"))
+            return
+
+        self.flg_showOnlySavedInterfaceNames = False
+        for link in globals.GApp.topology.links:
+            link.labelSouceIf = None
+            link.labelDestIf = None
+            link.adjust()
+
+        QtGui.QMessageBox.information(self, translate("Workspace", "Interface labels"), translate("Workspace", "Interface labels have been reset"))
+
     def __action_TelnetAll(self):
         """ Telnet to all started IOS routers
         """
@@ -563,6 +622,14 @@ class Workspace(QMainWindow, Ui_MainWindow):
         for node in globals.GApp.topology.nodes.itervalues():
             if (isinstance(node, IOSRouter) or isinstance(node, AnyEmuDevice)) and node.get_dynagen_device().state == 'running':
                 node.console()
+                
+    def __action_ConsoleAuxAll(self):
+        """ Console AUX to all started IOS routers
+        """
+    
+        for node in globals.GApp.topology.nodes.itervalues():
+            if isinstance(node, IOSRouter) and node.get_dynagen_device().state == 'running':
+                node.aux()
 
     def __launchProgressDialog(self, action, text, autostart=False):
         """ Launch a progress dialog and do a action
@@ -722,24 +789,43 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """ Create a new project
         """
 
-        projectDialog = ProjectDialog()
-        projectDialog.pushButtonOpenProject.hide()
-        self.projectWorkdir
-        self.projectConfigs
+
+        if len(globals.GApp.dynagen.devices):
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"),
+                                               translate("Workspace", "Do you want to clear the current topology?"), QtGui.QMessageBox.Yes, \
+                                               QtGui.QMessageBox.No)
+            if reply == QtGui.QMessageBox.No:
+                return
+
+        self.clear()
+        projectDialog = ProjectDialog(newProject=True)
+        self.projectWorkdir = None
+        self.projectConfigs = None
         projectDialog.show()
         self.centerDialog(projectDialog)
         projectDialog.exec_()
-        
-    def __action_EditProject(self):
-        """ Edit a project
+
+    def __action_SaveProjectAs(self):
+        """ Save project in a new location
         """
-        
-        if not self.projectFile:
-            QtGui.QMessageBox.information(self, translate("Workspace", "Project"),  translate("Workspace", "Please create a new project first"))
-            return
+
+        running_nodes = False
+        for node in globals.GApp.topology.nodes.itervalues():
+            if (isinstance(node, IOSRouter) or isinstance(node, AnyEmuDevice)) and node.get_dynagen_device().state == 'running':
+                running_nodes = True
+
+        if running_nodes:
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "This action is going to stop all your devices and captures, would you like to continue anyway?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            if reply == QtGui.QMessageBox.No:
+                return
+
         projectDialog = ProjectDialog(self.projectFile, self.projectWorkdir, self.projectConfigs)
-        projectDialog.pushButtonOpenProject.hide()
-        projectDialog.setWindowTitle("Edit Project")
+        projectDialog.pushButtonOpenProject.setEnabled(False)
+        if self.projectFile:
+            projectDialog.setWindowTitle("Save Project As...")
+        self.projectWorkdir = None
+        self.projectConfigs = None
         projectDialog.show()
         self.centerDialog(projectDialog)
         projectDialog.exec_()
@@ -748,7 +834,6 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """ Create a new project
         """
 
-        projectWorkdircopy = self.projectWorkdir
         globals.GApp.workspace.setWindowTitle("GNS3")
         self.projectWorkdir = None
         self.projectConfigs = None
@@ -766,55 +851,88 @@ class Workspace(QMainWindow, Ui_MainWindow):
                 os.mkdir(self.projectConfigs)
             except (OSError, IOError), e:
                 print "Warning: cannot create directory: " + self.projectConfigs + ": " + e.strerror
+        
         if len(globals.GApp.dynagen.devices):
-            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"),
-                                               translate("Workspace", "Do you want to apply the project settings to the current topology? (can take some time)"), QtGui.QMessageBox.Yes, \
-                                               QtGui.QMessageBox.No)
-            if reply == QtGui.QMessageBox.Yes:
-                if self.projectWorkdir:
-                    # stop all router and firewall nodes
-                    for node in globals.GApp.topology.nodes.values():
-                        if isinstance(node, IOSRouter) or isinstance(node, AnyEmuDevice):
-                            node.stopNode()
-                    # move dynamips & Qemu files
-                    for node in globals.GApp.topology.nodes.values():
-                        if isinstance(node, IOSRouter) and self.projectWorkdir != node.hypervisor.workingdir:
-                            dynamips_files = glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '?' + node.hostname + '*') + \
-                            [os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_dynagen_device().formatted_ghost_file()]
-                            for file in dynamips_files:
-                                try:
-                                    shutil.move(file, self.projectWorkdir)
-                                except (OSError, IOError), e:
-                                    debug("Warning: cannot move " + file + " to " + self.projectWorkdir)
-                                    continue
-                                except:
-                                    continue
-                        if isinstance(node, AnyEmuDevice) and self.projectWorkdir != node.qemu.workingdir:
-                            qemu_files = glob.glob(os.path.normpath(node.qemu.workingdir) + os.sep + node.hostname)
-                            for file in qemu_files:
-                                try:
-                                    shutil.move(file, self.projectWorkdir + os.sep + node.hostname)
-                                except (OSError, IOError), e:
-                                    debug("Warning: cannot move " + file + " to " + self.projectWorkdir)
-                                    continue
-                    # set the new working directory
-                    try:
-                        for hypervisor in globals.GApp.dynagen.dynamips.values():
-                            hypervisor.workingdir = self.projectWorkdir
-                    except lib.DynamipsError, msg:
-                        QtGui.QMessageBox.critical(self, unicode(translate("Workspace", "Dynamips error"), "%s: %s") % (self.projectWorkdir, unicode(msg)))
-            elif globals.GApp.topology.changed == True:
-                reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to save the current topology?"),
-                                           QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
-                if reply == QtGui.QMessageBox.Yes:
-                    save = self.projectWorkdir
-                    self.projectWorkdir = projectWorkdircopy
-                    self.__action_Save()
-                    self.projectWorkdir = save
-                globals.GApp.topology.clear()
-                for item in globals.GApp.topology.items():
-                    globals.GApp.topology.removeItem(item)
-        self.__action_Save()
+            if self.projectConfigs:
+                for node in globals.GApp.topology.nodes.values():
+                    if isinstance(node, IOSRouter) and node.router.cnfg:
+                        try:
+                            shutil.copy(node.router.cnfg, self.projectConfigs)
+                        except (OSError, IOError), e:
+                            debug("Warning: cannot copy " + file + " to " + self.projectConfigs)
+                            continue
+                        except:
+                            continue
+                        config = os.path.basename(node.router.cnfg)
+                        node.router.cnfg = self.projectConfigs + os.sep + config
+
+            if self.projectWorkdir:
+                
+
+                unbase = False
+                instances = map(lambda node: isinstance(node, QemuDevice) or isinstance(node, JunOS) or isinstance(node, IDS), globals.GApp.topology.nodes.values())
+                if True in instances:
+                    reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to unbase the Qemu disk(s)? (useful if you want to distribute your lab but it will increase the total size)"),
+                                                       QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+                    
+                    if reply == QtGui.QMessageBox.Yes:
+                        unbase = True
+
+                # stop the node before moving files
+                for node in globals.GApp.topology.nodes.values():
+                    if (isinstance(node, IOSRouter) and self.projectWorkdir != node.hypervisor.workingdir) or (isinstance(node, AnyEmuDevice) and self.projectWorkdir != node.qemu.workingdir):
+                        node.stopNode()
+                        
+                globals.GApp.mainWindow.capturesDock.stopAllCaptures()
+
+                # move dynamips & Qemu files
+                for node in globals.GApp.topology.nodes.values():
+                    if isinstance(node, IOSRouter) and self.projectWorkdir != node.hypervisor.workingdir:
+
+                        dynamips_files = glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_nvram*')
+                        dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_disk*')
+                        dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_slot*')
+                        dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_rom')
+                        dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_*flash*')
+                        dynamips_files += [os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_dynagen_device().formatted_ghost_file()]
+                            
+                        for file in dynamips_files:
+                            try:
+                                shutil.copy(file, self.projectWorkdir)
+                            except (OSError, IOError), e:
+                                debug("Warning: cannot copy " + file + " to " + self.projectWorkdir)
+                                continue
+                            except:
+                                continue
+                            
+                        # clean the original working directory
+                        self.clear_workdir(os.path.normpath(node.hypervisor.workingdir))
+                    
+                    if (isinstance(node, QemuDevice) or isinstance(node, JunOS) or isinstance(node, IDS)) and unbase:
+                        node.get_dynagen_device().unbase()
+
+                    if isinstance(node, AnyEmuDevice) and self.projectWorkdir != node.qemu.workingdir:
+                        
+                        # Stop this node
+                        node.stopNode()
+                        qemu_files = glob.glob(os.path.normpath(node.qemu.workingdir) + os.sep + node.hostname)
+                        for file in qemu_files:
+                            try:
+                                shutil.copytree(file, self.projectWorkdir + os.sep + node.hostname)
+                            except (OSError, IOError), e:
+                                debug("Warning: cannot copy " + file + " to " + self.projectWorkdir)
+                                continue
+                            except:
+                                continue
+
+                # set the new working directory
+                try:
+                    for hypervisor in globals.GApp.dynagen.dynamips.values():
+                        hypervisor.workingdir = self.projectWorkdir
+                except lib.DynamipsError, msg:
+                    QtGui.QMessageBox.critical(self, unicode(translate("Workspace", "Dynamips error"), "%s: %s") % (self.projectWorkdir, unicode(msg)))
+
+        self.__action_Save(auto=True)
         self.setWindowTitle("GNS3 Project - " + self.projectFile) 
 
     def __action_Snapshot(self):
@@ -826,81 +944,113 @@ class Workspace(QMainWindow, Ui_MainWindow):
         self.centerDialog(snapDialog)
         snapDialog.exec_()
 
-    def createSnapshot(self):
+    def createSnapshot(self, name):
         """ Create a new snapshot of the current topology
         """
 
         if self.projectFile is None:
             if self.__action_SaveAs() == False:
                 return
-            self.createSnapshot()
+            self.createSnapshot(name)
             return
 
         projectName = os.path.basename(self.projectFile)
         projectDir = os.path.dirname(self.projectFile)
-        snapshot_dir = projectDir + os.sep + projectName.replace('.net', '') + '_snapshot_' + time.strftime("%d%m%y_%H%M%S")
+        snapshot_dir = projectDir + os.sep + projectName.replace('.net', '') + '_' + name + '_snapshot_' + time.strftime("%d%m%y_%H%M%S")
+        snapshot_workdir = snapshot_dir + os.sep + 'working'
+        snapshot_configs = snapshot_dir + os.sep + 'configs'
 
         try:
             os.mkdir(snapshot_dir)
+            os.mkdir(snapshot_workdir)
+            os.mkdir(snapshot_configs)
         except (OSError, IOError), e:
-            QtGui.QMessageBox.critical(self, translate("Workspace", "Snapshot"), unicode(translate("Workspace", "Cannot create directory %s: %s")) % (snapshot_dir, e.strerror))
+            QtGui.QMessageBox.critical(self, translate("Workspace", "Snapshot"), unicode(translate("Workspace", "Cannot create directories in %s: %s")) % (snapshot_dir, e.strerror))
             return
-        
+
         splash = QtGui.QSplashScreen(QtGui.QPixmap(":images/logo_gns3_splash.png"))
         splash.show()
         splash.showMessage(translate("Workspace", "Please wait while creating a snapshot"))
         globals.GApp.processEvents(QtCore.QEventLoop.AllEvents | QtCore.QEventLoop.WaitForMoreEvents, 1000)
         
-        # copy dynamips & Qemu files
+        # copy dynamips & Qemu files + IOS configs
         for node in globals.GApp.topology.nodes.values():
             if isinstance(node, IOSRouter):
                 dynamips_files = glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_nvram*')
-                dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_ssa*')
                 dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_disk*')
                 dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_slot*')
-                dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_flash*')
+                dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_rom')
+                dynamips_files += glob.glob(os.path.normpath(node.hypervisor.workingdir) + os.sep + node.get_platform() + '_' + node.hostname + '_*flash*')
                 for file in dynamips_files:
                     try:
-                        shutil.copy(file, snapshot_dir)
+                        shutil.copy(file, snapshot_workdir)
                     except (OSError, IOError), e:
-                        debug("Warning: cannot copy " + file + " to " + snapshot_dir + ": " + e.strerror)
+                        debug("Warning: cannot copy " + file + " to " + snapshot_workdir + ": " + e.strerror)
                         continue
+                if node.router.cnfg:
+                    try:
+                        shutil.copy(node.router.cnfg, snapshot_configs)
+                    except (OSError, IOError), e:
+                        debug("Warning: cannot copy " + file + " to " + snapshot_configs)
+                        continue
+                    config = os.path.basename(node.router.cnfg)
+                    node.router.cnfg = snapshot_configs + os.sep + config
+                
             if isinstance(node, AnyEmuDevice):
                 qemu_files = glob.glob(os.path.normpath(node.qemu.workingdir) + os.sep + node.hostname)
                 for file in qemu_files:
                     try:
-                        shutil.copytree(file, snapshot_dir + os.sep + node.hostname)
+                        shutil.copytree(file, snapshot_workdir + os.sep + node.hostname)
                     except (OSError, IOError), e:
-                        debug("Warning: cannot copy " + file + " to " + snapshot_dir + ": " + e.strerror)
+                        debug("Warning: cannot copy " + file + " to " + snapshot_workdir + ": " + e.strerror)
                         continue
-                        
+            
         try:
             for hypervisor in globals.GApp.dynagen.dynamips.values():
-                hypervisor.workingdir = snapshot_dir
+                hypervisor.workingdir = snapshot_workdir
         except lib.DynamipsError, msg:
             QtGui.QMessageBox.critical(self, translate("Workspace", "Dynamips error"), unicode(translate("Workspace", "Dynamips error: %s")) % msg)
 
         save_wd = self.projectWorkdir
+        if not self.projectWorkdir:
+            self.projectWorkdir = globals.GApp.systconf['dynamips'].workdir
         save_cfg = self.projectConfigs
         save_projectFile = self.projectFile
-        self.projectConfigs = snapshot_dir
-        self.projectWorkdir = snapshot_dir
+        self.projectConfigs = snapshot_configs
+        self.projectWorkdir = snapshot_workdir
         self.projectFile = snapshot_dir + os.sep + projectName
-        self.__action_Save()
-        self.projectWorkdir = save_wd
+        self.__action_Save(auto=True)
         self.projectFile = save_projectFile
         self.projectConfigs = save_cfg
+        self.projectWorkdir = save_wd
 
         try:
-            for hypervisor in globals.GApp.dynagen.dynamips.values():
-                hypervisor.workingdir = self.projectWorkdir
+            if self.projectWorkdir:
+                for hypervisor in globals.GApp.dynagen.dynamips.values():
+                    hypervisor.workingdir = self.projectWorkdir
+            else:
+                for hypervisor in globals.GApp.dynagen.dynamips.values():
+                    hypervisor.workingdir = globals.GApp.systconf['dynamips'].workdir
+            if self.projectConfigs:
+                for node in globals.GApp.topology.nodes.values():
+                    if isinstance(node, IOSRouter) and node.router.cnfg:
+                        config = os.path.basename(node.router.cnfg)
+                        node.router.cnfg = self.projectConfigs + os.sep + config
         except lib.DynamipsError, msg:
-            QtGui.QMessageBox.critical(self, translate("Workspace", "Dynamips error"), unicode(translate("Workspace", "Dynamips error: %s")) % msg)
+            QtGui.QMessageBox.critical(self, translate("Workspace", "Dynamips error"), unicode(translate("Workspace", "Dynamips error!!: %s")) % msg)
 
     def __action_OpenFile(self):
         """ Open a file
         """
 
+        if len(globals.GApp.topology.nodes) and globals.GApp.topology.changed == True:
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to save the current topology?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No, QtGui.QMessageBox.Cancel)
+            if reply == QtGui.QMessageBox.Yes:
+                self.__action_Save()
+            elif reply == QtGui.QMessageBox.Cancel:
+                return
+
         self.openFile()
 
     def openFile(self):
@@ -927,8 +1077,17 @@ class Workspace(QMainWindow, Ui_MainWindow):
             globals.GApp.topology.changed = False
         except IOError, (errno, strerror):
             QtGui.QMessageBox.critical(self, 'Open',  u'Open: ' + strerror)
+        except (lib.DynamipsErrorHandled, socket.error):
+            QtGui.QMessageBox.critical(self, unicode(translate("Workspace", "Dynamips error")), translate("Workspace", "Connection lost with Dynamips hypervisor (crashed?)"))
 
-    def __action_Save(self):
+    def __action_Autosave(self):
+        """ Autosave feature
+        """
+
+        print translate("Workspace", "Auto-saving ... Next one in %s seconds" % str(globals.GApp.systconf['general'].autosave))
+        self.__action_Save(auto=True)
+
+    def __action_Save(self, auto=False):
         """ Save to a file (scenario or dynagen .NET format)
         """
 
@@ -937,8 +1096,13 @@ class Workspace(QMainWindow, Ui_MainWindow):
 
         try:
             net = netfile.NETFile()
-            net.export_net_file(self.projectFile)
+            net.export_net_file(self.projectFile, auto)
             globals.GApp.topology.changed = False
+            autosave = globals.GApp.systconf['general'].autosave
+            if autosave > 0:
+                self.timer.start(autosave * 1000)
+            else:
+                self.timer.stop()
         except IOError, (errno, strerror):
             QtGui.QMessageBox.critical(self, 'Open',  u'Open: ' + strerror)
 
@@ -946,7 +1110,7 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """ Save as (scenario or dynagen .NET format)
         """
 
-        (path, selected) = fileBrowser(translate("Workspace", "Save Project As"),
+        (path, selected) = fileBrowser(translate("Workspace", "Save As..."),
                                 filter='NET file (*.net);;All files (*.*)', directory=os.path.normpath(globals.GApp.systconf['general'].project_path), parent=self).getSaveFile()
 
         if path != None and path != '':
@@ -965,10 +1129,26 @@ class Workspace(QMainWindow, Ui_MainWindow):
         """ Ask to close GNS3
         """
 
+        running_nodes = False
+        for node in globals.GApp.topology.nodes.itervalues():
+            if (isinstance(node, IOSRouter) or isinstance(node, AnyEmuDevice)) and node.get_dynagen_device().state == 'running':
+                running_nodes = True
+
         if len(globals.GApp.topology.nodes) and globals.GApp.topology.changed == True:
-            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to save the topology before you quit?"),
-                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "Would you like to save the current topology?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No, QtGui.QMessageBox.Cancel)
             if reply == QtGui.QMessageBox.Yes:
                 self.__action_Save()
+            elif reply == QtGui.QMessageBox.Cancel:
+                event.ignore()
+                return
+
+        elif running_nodes:
+            reply = QtGui.QMessageBox.question(self, translate("Workspace", "Message"), translate("Workspace", "You have running nodes and you may loose your configurations inside them, would you like to continue anyway?"),
+                                               QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            if reply == QtGui.QMessageBox.No:
+                event.ignore()
+                return
+            
         self.clear()
         event.accept()
